@@ -1,3 +1,5 @@
+# fmt: off
+
 # Copyright (C) 2008 CSC - Scientific Computing Ltd.
 """This module defines an ASE interface to VASP.
 
@@ -22,11 +24,12 @@ import os
 import shutil
 import warnings
 from os.path import isfile, islink, join
-from typing import List, Sequence, Tuple
+from typing import List, Sequence, TextIO, Tuple, Union
 
 import numpy as np
 
 import ase
+from ase import Atoms
 from ase.calculators.calculator import kpts2ndarray
 from ase.calculators.vasp.setups import get_default_setups
 from ase.config import cfg
@@ -117,22 +120,27 @@ def set_ldau(ldau_param, luj_params, symbol_count):
     return ldau_dct
 
 
-def test_nelect_charge_compitability(nelect, charge, nelect_from_ppp):
-    # We need to determine the nelect resulting from a given
-    # charge in any case if it's != 0, but if nelect is
-    # additionally given explicitly, then we need to determine it
-    # even for net charge of 0 to check for conflicts
-    if charge is not None and charge != 0:
+def _calc_nelect_from_charge(
+    nelect: Union[float, None],
+    charge: Union[float, None],
+    nelect_from_ppp: float,
+) -> Union[float, None]:
+    """Determine nelect resulting from a given charge if charge != 0.0.
+
+    If nelect is additionally given explicitly, then we need to determine it
+    even for net charge of 0 to check for conflicts.
+
+    """
+    if charge is not None and charge != 0.0:
         nelect_from_charge = nelect_from_ppp - charge
         if nelect and nelect != nelect_from_charge:
-            raise ValueError('incompatible input parameters: '
-                             f'nelect={nelect}, but charge={charge} '
-                             '(neutral nelect is '
-                             f'{nelect_from_ppp})')
-        print(nelect_from_charge)
+            raise ValueError(
+                'incompatible input parameters: '
+                f'nelect={nelect}, but charge={charge} '
+                f'(neutral nelect is {nelect_from_ppp})'
+            )
         return nelect_from_charge
-    else:
-        return nelect
+    return nelect  # NELECT explicitly given in INCAR (`None` if not given)
 
 
 def get_pp_setup(setup) -> Tuple[dict, Sequence[int]]:
@@ -1496,7 +1504,7 @@ class GenerateVaspInput:
                 raise RuntimeError(msg)
         return ppp_list
 
-    def initialize(self, atoms):
+    def initialize(self, atoms: Atoms) -> None:
         """Initialize a VASP calculation
 
         Constructs the POTCAR file (does not actually write it).
@@ -1534,32 +1542,34 @@ class GenerateVaspInput:
         # Check if the necessary POTCAR files exists and
         # create a list of their paths.
         atomtypes = atoms.get_chemical_symbols()
-        self.symbol_count = []
+        self.symbol_count: list[tuple[str, int]] = []
         for m in special_setups:
-            self.symbol_count.append([atomtypes[m], 1])
-        for m in symbols:
-            self.symbol_count.append([m, symbolcount[m]])
+            self.symbol_count.append((atomtypes[m], 1))
+        for s in symbols:
+            self.symbol_count.append((s, symbolcount[s]))
 
         # create pseudopotential list
-        self.ppp_list = self._build_pp_list(atoms,
-                                            setups=setups,
-                                            special_setups=special_setups)
+        self.ppp_list = self._build_pp_list(
+            atoms,
+            setups=setups,
+            special_setups=special_setups,
+        )
 
         self.converged = None
         self.setups_changed = None
 
-    def default_nelect_from_ppp(self):
+    def default_nelect_from_ppp(self) -> float:
         """ Get default number of electrons from ppp_list and symbol_count
 
         "Default" here means that the resulting cell would be neutral.
         """
-        symbol_valences = []
+        symbol_valences: list[tuple[str, float]] = []
         for filename in self.ppp_list:
             with open_potcar(filename=filename) as ppp_file:
                 r = read_potcar_numbers_of_electrons(ppp_file)
                 symbol_valences.extend(r)
         assert len(self.symbol_count) == len(symbol_valences)
-        default_nelect = 0
+        default_nelect = 0.0
         for ((symbol1, count),
              (symbol2, valence)) in zip(self.symbol_count, symbol_valences):
             assert symbol1 == symbol2
@@ -1639,7 +1649,7 @@ class GenerateVaspInput:
 
         if 'charge' in self.input_params and self.input_params[
                 'charge'] is not None:
-            nelect_val = test_nelect_charge_compitability(
+            nelect_val = _calc_nelect_from_charge(
                 self.float_params['nelect'],
                 self.input_params['charge'],
                 self.default_nelect_from_ppp())
@@ -1780,6 +1790,8 @@ class GenerateVaspInput:
                 raise ValueError("KSPACING value {} is not allowable. "
                                  "Please use None or a positive number."
                                  "".format(self.float_params['kspacing']))
+        if self.input_params['kpts'] is None:
+            return
 
         kpointstring = format_kpoints(
             kpts=self.input_params['kpts'],
@@ -2073,21 +2085,27 @@ def open_potcar(filename):
         raise ValueError(f'Invalid POTCAR filename: "{filename}"')
 
 
-def read_potcar_numbers_of_electrons(file_obj):
-    """ Read list of tuples (atomic symbol, number of valence electrons)
-    for each atomtype from a POTCAR file."""
-    nelect = []
-    lines = file_obj.readlines()
+def read_potcar_numbers_of_electrons(fd: TextIO, /) -> list[tuple[str, float]]:
+    """Read number of valence electrons for each atomtype from a POTCAR file.
+
+    Returns
+    -------
+    list[tuple[str, float]]
+        List of (atomic symbol, number of valence electrons).
+
+    """
+    nelect: list[tuple[str, float]] = []
+    lines = fd.readlines()
     for n, line in enumerate(lines):
         if 'TITEL' in line:
             symbol = line.split('=')[1].split()[1].split('_')[0].strip()
-            valence = float(
-                lines[n + 4].split(';')[1].split('=')[1].split()[0].strip())
-            nelect.append((symbol, valence))
+            linep4 = lines[n + 4]
+            zval = float(linep4.split(';')[1].split('=')[1].split()[0].strip())
+            nelect.append((symbol, zval))
     return nelect
 
 
-def count_symbols(atoms, exclude=()):
+def count_symbols(atoms: Atoms, exclude=()) -> tuple[list[str], dict[str, int]]:
     """Count symbols in atoms object, excluding a set of indices
 
     Parameters:
@@ -2108,8 +2126,8 @@ def count_symbols(atoms, exclude=()):
     >>> count_symbols(atoms, exclude=(1, 2, 3))
     (['Na', 'Cl'], {'Na': 3, 'Cl': 2})
     """
-    symbols = []
-    symbolcount = {}
+    symbols: list[str] = []
+    symbolcount: dict[str, int] = {}
     for m, symbol in enumerate(atoms.symbols):
         if m in exclude:
             continue
