@@ -1,3 +1,5 @@
+# fmt: off
+
 # Copyright (C) 2008 CSC - Scientific Computing Ltd.
 """This module defines an ASE interface to VASP.
 
@@ -1196,7 +1198,7 @@ class Vasp(GenerateVaspInput, Calculator):  # type: ignore[misc]
                     i_freq.append(float(data[-2]))
         return freq, i_freq
 
-    def _read_massweighted_hessian_xml(self) -> np.ndarray:
+    def _read_massweighted_hessian_xml(self):
         """Read the Mass Weighted Hessian from vasprun.xml.
 
         Returns:
