@@ -1,3 +1,5 @@
+# fmt: off
+
 # Note:
 # Try to avoid module level import statements here to reduce
 # import time during CLI execution
@@ -18,7 +20,7 @@ class CLICommand:
         ase build <formula> ...
 
     where <formula> must be one of the formulas known to ASE
-    (see here: https://wiki.fysik.dtu.dk/ase/ase/build/build.html#molecules).
+    (see here: https://ase-lib.org/ase/build/build.html#molecules).
 
     Bulk:
 
