@@ -50,8 +50,10 @@ class KeyDescription:
 
     def __repr__(self):
         cls = type(self).__name__
-        return (f'{cls}({self.key!r}, {self.shortdesc!r}, {self.longdesc!r}, '
-                f'unit={self.unit!r})')
+        return (
+            f'{cls}({self.key!r}, {self.shortdesc!r}, {self.longdesc!r}, '
+            f'unit={self.unit!r})'
+        )
 
     # The templates like to sort key descriptions by shortdesc.
     def __eq__(self, other):
@@ -63,24 +65,31 @@ class KeyDescription:
 
 def get_key_descriptions():
     KD = KeyDescription
-    return {keydesc.key: keydesc for keydesc in [
-        KD('id', 'ID', 'Uniqe row ID'),
-        KD('age', 'Age', 'Time since creation'),
-        KD('formula', 'Formula', 'Chemical formula'),
-        KD('pbc', 'PBC', 'Periodic boundary conditions'),
-        KD('user', 'Username'),
-        KD('calculator', 'Calculator', 'ASE-calculator name'),
-        KD('energy', 'Energy', 'Total energy', unit='eV'),
-        KD('natoms', 'Number of atoms'),
-        KD('fmax', 'Maximum force', unit='eV/Å'),
-        KD('smax', 'Maximum stress', 'Maximum stress on unit cell',
-           unit='eV/Å³'),
-        KD('charge', 'Charge', 'Net charge in unit cell', unit='|e|'),
-        KD('mass', 'Mass', 'Sum of atomic masses in unit cell', unit='au'),
-        KD('magmom', 'Magnetic moment', unit='μ_B'),
-        KD('unique_id', 'Unique ID', 'Random (unique) ID'),
-        KD('volume', 'Volume', 'Volume of unit cell', unit='Å³')
-    ]}
+    return {
+        keydesc.key: keydesc
+        for keydesc in [
+            KD('id', 'ID', 'Uniqe row ID'),
+            KD('age', 'Age', 'Time since creation'),
+            KD('formula', 'Formula', 'Chemical formula'),
+            KD('pbc', 'PBC', 'Periodic boundary conditions'),
+            KD('user', 'Username'),
+            KD('calculator', 'Calculator', 'ASE-calculator name'),
+            KD('energy', 'Energy', 'Total energy', unit='eV'),
+            KD('natoms', 'Number of atoms'),
+            KD('fmax', 'Maximum force', unit='eV/Å'),
+            KD(
+                'smax',
+                'Maximum stress',
+                'Maximum stress on unit cell',
+                unit='eV/Å³',
+            ),
+            KD('charge', 'Charge', 'Net charge in unit cell', unit='|e|'),
+            KD('mass', 'Mass', 'Sum of atomic masses in unit cell', unit='au'),
+            KD('magmom', 'Magnetic moment', unit='μ_B'),
+            KD('unique_id', 'Unique ID', 'Random (unique) ID'),
+            KD('volume', 'Volume', 'Volume of unit cell', unit='Å³'),
+        ]
+    }
 
 
 def now():
@@ -88,48 +97,69 @@ def now():
     return (time() - T2000) / YEAR
 
 
-seconds = {'s': 1,
-           'm': 60,
-           'h': 3600,
-           'd': 86400,
-           'w': 604800,
-           'M': 2629800,
-           'y': YEAR}
+seconds = {
+    's': 1,
+    'm': 60,
+    'h': 3600,
+    'd': 86400,
+    'w': 604800,
+    'M': 2629800,
+    'y': YEAR,
+}
 
-longwords = {'s': 'second',
-             'm': 'minute',
-             'h': 'hour',
-             'd': 'day',
-             'w': 'week',
-             'M': 'month',
-             'y': 'year'}
+longwords = {
+    's': 'second',
+    'm': 'minute',
+    'h': 'hour',
+    'd': 'day',
+    'w': 'week',
+    'M': 'month',
+    'y': 'year',
+}
 
-ops = {'<': operator.lt,
-       '<=': operator.le,
-       '=': operator.eq,
-       '>=': operator.ge,
-       '>': operator.gt,
-       '!=': operator.ne}
+ops = {
+    '<': operator.lt,
+    '<=': operator.le,
+    '=': operator.eq,
+    '>=': operator.ge,
+    '>': operator.gt,
+    '!=': operator.ne,
+}
 
 invop = {'<': '>=', '<=': '>', '>=': '<', '>': '<=', '=': '!=', '!=': '='}
 
 word = re.compile('[_a-zA-Z][_0-9a-zA-Z]*$')
 
-reserved_keys = set(all_properties +
-                    all_changes +
-                    list(atomic_numbers) +
-                    ['id', 'unique_id', 'ctime', 'mtime', 'user',
-                     'fmax', 'smax',
-                     'momenta', 'constraints', 'natoms', 'formula', 'age',
-                     'calculator', 'calculator_parameters',
-                     'key_value_pairs', 'data'])
+reserved_keys = set(
+    all_properties
+    + all_changes
+    + list(atomic_numbers)
+    + [
+        'id',
+        'unique_id',
+        'ctime',
+        'mtime',
+        'user',
+        'fmax',
+        'smax',
+        'momenta',
+        'constraints',
+        'natoms',
+        'formula',
+        'age',
+        'calculator',
+        'calculator_parameters',
+        'key_value_pairs',
+        'data',
+    ]
+)
 
 numeric_keys = {'id', 'energy', 'magmom', 'charge', 'natoms'}
 
 
 def check(key_value_pairs):
     for key, value in key_value_pairs.items():
-        if key == "external_tables":
+        if key == 'external_tables':
             # Checks for external_tables are not
             # performed
             continue
@@ -145,19 +175,23 @@ def check(key_value_pairs):
                 'It is best not to use keys ({0}) that are also a '
                 'chemical formula.  If you do a "db.select({0!r})",'
                 'you will not find rows with your key.  Instead, you wil get '
-                'rows containing the atoms in the formula!'.format(key))
+                'rows containing the atoms in the formula!'.format(key)
+            )
         if not isinstance(value, (numbers.Real, str, np.bool_)):
             raise ValueError(f'Bad value for {key!r}: {value}')
         if isinstance(value, str):
             for t in [bool, int, float]:
                 if str_represents(value, t):
                     raise ValueError(
-                        'Value ' + value + ' is put in as string ' +
-                        'but can be interpreted as ' +
-                        f'{t.__name__}! Please convert ' +
-                        f'to {t.__name__} before ' +
-                        'writing to the database OR change ' +
-                        'to a different string.')
+                        'Value '
+                        + value
+                        + ' is put in as string '
+                        + 'but can be interpreted as '
+                        + f'{t.__name__}! Please convert '
+                        + f'to {t.__name__} before '
+                        + 'writing to the database OR change '
+                        + 'to a different string.'
+                    )
 
 
 def str_represents(value, t=int):
@@ -165,21 +199,30 @@ def str_represents(value, t=int):
     return isinstance(new_value, t)
 
 
-def connect(name, type='extract_from_name', create_indices=True,
-            use_lock_file=True, append=True, serial=False):
+def connect(
+    name,
+    type='extract_from_name',
+    create_indices=True,
+    use_lock_file=True,
+    append=True,
+    serial=False,
+    **db_kwargs,
+):
     """Create connection to database.
 
     name: str
         Filename or address of database.
     type: str
-        One of 'json', 'db', 'postgresql',
-        (JSON, SQLite, PostgreSQL).
+        One of 'json', 'db', 'postgresql', 'mysql', 'aselmdb'
+        (JSON, SQLite, PostgreSQL, MYSQL, ASELMDB).
         Default is 'extract_from_name', which will guess the type
         from the name.
     use_lock_file: bool
         You can turn this off if you know what you are doing ...
     append: bool
         Use append=False to start a new database.
+    db_kwargs: dict
+        Optional extra kwargs to pass on to the underlying db
     """
 
     if isinstance(name, PurePath):
@@ -190,8 +233,7 @@ def connect(name, type='extract_from_name', create_indices=True,
             type = None
         elif not isinstance(name, str):
             type = 'json'
-        elif (name.startswith('postgresql://') or
-              name.startswith('postgres://')):
+        elif name.startswith('postgresql://') or name.startswith('postgres://'):
             type = 'postgresql'
         elif name.startswith('mysql://') or name.startswith('mariadb://'):
             type = 'mysql'
@@ -201,7 +243,7 @@ def connect(name, type='extract_from_name', create_indices=True,
                 raise ValueError('No file extension or database type given')
 
     if type is None:
-        return Database()
+        return Database(**db_kwargs)
 
     if not append and world.rank == 0:
         if isinstance(name, str) and os.path.isfile(name):
@@ -212,23 +254,37 @@ def connect(name, type='extract_from_name', create_indices=True,
 
     if type == 'json':
         from ase.db.jsondb import JSONDatabase
-        return JSONDatabase(name, use_lock_file=use_lock_file, serial=serial)
+
+        return JSONDatabase(
+            name, use_lock_file=use_lock_file, serial=serial, **db_kwargs
+        )
     if type == 'db':
         from ase.db.sqlite import SQLite3Database
-        return SQLite3Database(name, create_indices, use_lock_file,
-                               serial=serial)
+
+        return SQLite3Database(
+            name, create_indices, use_lock_file, serial=serial, **db_kwargs
+        )
     if type == 'postgresql':
-        from ase.db.postgresql import PostgreSQLDatabase
-        return PostgreSQLDatabase(name)
+        from ase_db_backends.postgresql import PostgreSQLDatabase
+
+        return PostgreSQLDatabase(name, **db_kwargs)
 
     if type == 'mysql':
-        from ase.db.mysql import MySQLDatabase
-        return MySQLDatabase(name)
+        from ase_db_backends.mysql import MySQLDatabase
+
+        return MySQLDatabase(name, **db_kwargs)
+
+    if type == 'aselmdb':
+        from ase_db_backends.aselmdb import LMDBDatabase
+
+        return LMDBDatabase(name, **db_kwargs)
+
     raise ValueError('Unknown database type: ' + type)
 
 
 def lock(method):
     """Decorator for using a lock-file."""
+
     @functools.wraps(method)
     def new_method(self, *args, **kwargs):
         if self.lock is None:
@@ -236,6 +292,7 @@ def lock(method):
         else:
             with self.lock:
                 return method(self, *args, **kwargs)
+
     return new_method
 
 
@@ -287,8 +344,9 @@ def parse_selection(selection, **kwargs):
                 except ValueError:
                     keys.append(expression)
                 else:
-                    comparisons.extend((symbol, '>', n - 1)
-                                       for symbol, n in count.items())
+                    comparisons.extend(
+                        (symbol, '>', n - 1) for symbol, n in count.items()
+                    )
             continue
         key, value = expression.split(op)
         comparisons.append((key, op, value))
@@ -307,15 +365,17 @@ def parse_selection(selection, **kwargs):
                 raise ValueError('Use fomula=...')
             f = Formula(value)
             count = f.count()
-            cmps.extend((atomic_numbers[symbol], '=', n)
-                        for symbol, n in count.items())
+            cmps.extend(
+                (atomic_numbers[symbol], '=', n) for symbol, n in count.items()
+            )
             key = 'natoms'
             value = len(f)
         elif key in atomic_numbers:
             key = atomic_numbers[key]
             value = int(value)
         elif isinstance(value, str):
-            value = convert_str_to_int_float_bool_or_str(value)
+            if key != 'unique_id':
+                value = convert_str_to_int_float_bool_or_str(value)
         if key in numeric_keys and not isinstance(value, (int, float)):
             msg = 'Wrong type for "{}{}{}" - must be a number'
             raise ValueError(msg.format(key, op, value))
@@ -327,8 +387,13 @@ def parse_selection(selection, **kwargs):
 class Database:
     """Base class for all databases."""
 
-    def __init__(self, filename=None, create_indices=True,
-                 use_lock_file=False, serial=False):
+    def __init__(
+        self,
+        filename: str = None,
+        create_indices: bool = True,
+        use_lock_file: bool = False,
+        serial: bool = False,
+    ):
         """Database object.
 
         serial: bool
@@ -340,14 +405,13 @@ class Database:
             filename = os.path.expanduser(filename)
         self.filename = filename
         self.create_indices = create_indices
+        self.lock = None
         if use_lock_file and isinstance(filename, str):
             self.lock = Lock(filename + '.lock', world=DummyMPI())
-        else:
-            self.lock = None
         self.serial = serial
 
         # Decription of columns and other stuff:
-        self._metadata: Dict[str, Any] = None
+        self._metadata = None
 
     @property
     def metadata(self) -> Dict[str, Any]:
@@ -403,9 +467,9 @@ class Database:
         anything and return None.
         """
 
-        for _ in self._select([],
-                              [(key, '=', value)
-                               for key, value in key_value_pairs.items()]):
+        for _ in self._select(
+            [], [(key, '=', value) for key, value in key_value_pairs.items()]
+        ):
             return None
 
         atoms = Atoms()
@@ -435,8 +499,9 @@ class Database:
     def __delitem__(self, id):
         self.delete([id])
 
-    def get_atoms(self, selection=None,
-                  add_additional_information=False, **kwargs):
+    def get_atoms(
+        self, selection=None, add_additional_information=False, **kwargs
+    ):
         """Get Atoms object.
 
         selection: int, str or list
@@ -467,9 +532,19 @@ class Database:
         return rows[0]
 
     @parallel_generator
-    def select(self, selection=None, filter=None, explain=False,
-               verbosity=1, limit=None, offset=0, sort=None,
-               include_data=True, columns='all', **kwargs):
+    def select(
+        self,
+        selection=None,
+        filter=None,
+        explain=False,
+        verbosity=1,
+        limit=None,
+        offset=0,
+        sort=None,
+        include_data=True,
+        columns='all',
+        **kwargs,
+    ):
         """Select rows.
 
         Return AtomsRow iterator with results.  Selection is done
@@ -516,11 +591,17 @@ class Database:
                 sort += 'name'
 
         keys, cmps = parse_selection(selection, **kwargs)
-        for row in self._select(keys, cmps, explain=explain,
-                                verbosity=verbosity,
-                                limit=limit, offset=offset, sort=sort,
-                                include_data=include_data,
-                                columns=columns):
+        for row in self._select(
+            keys,
+            cmps,
+            explain=explain,
+            verbosity=verbosity,
+            limit=limit,
+            offset=offset,
+            sort=sort,
+            include_data=include_data,
+            columns=columns,
+        ):
             if filter is None or filter(row):
                 yield row
 
@@ -540,8 +621,9 @@ class Database:
 
     @parallel_function
     @lock
-    def update(self, id, atoms=None, delete_keys=[], data=None,
-               **add_key_value_pairs):
+    def update(
+        self, id, atoms=None, delete_keys=[], data=None, **add_key_value_pairs
+    ):
         """Update and/or delete key-value pairs of row(s).
 
         id: int
@@ -560,11 +642,13 @@ class Database:
 
         if not isinstance(id, numbers.Integral):
             if isinstance(id, list):
-                err = ('First argument must be an int and not a list.\n'
-                       'Do something like this instead:\n\n'
-                       'with db:\n'
-                       '    for id in ids:\n'
-                       '        db.update(id, ...)')
+                err = (
+                    'First argument must be an int and not a list.\n'
+                    'Do something like this instead:\n\n'
+                    'with db:\n'
+                    '    for id in ids:\n'
+                    '        db.update(id, ...)'
+                )
                 raise ValueError(err)
             raise TypeError('id must be an int')
 
@@ -667,15 +751,14 @@ def o2b(obj: Any, parts: List[bytes]):
     if isinstance(obj, (list, tuple)):
         return [o2b(value, parts) for value in obj]
     if isinstance(obj, np.ndarray):
-        assert obj.dtype != object, \
+        assert obj.dtype != object, (
             'Cannot convert ndarray of type "object" to bytes.'
+        )
         offset = sum(len(part) for part in parts)
         if not np.little_endian:
             obj = obj.byteswap()
         parts.append(obj.tobytes())
-        return {'__ndarray__': [obj.shape,
-                                obj.dtype.name,
-                                offset]}
+        return {'__ndarray__': [obj.shape, obj.dtype.name, offset]}
     if isinstance(obj, complex):
         return {'__complex__': [obj.real, obj.imag]}
     objtype = obj.ase_objtype
@@ -683,8 +766,9 @@ def o2b(obj: Any, parts: List[bytes]):
         dct = o2b(obj.todict(), parts)
         dct['__ase_objtype__'] = objtype
         return dct
-    raise ValueError('Objects of type {type} not allowed'
-                     .format(type=type(obj)))
+    raise ValueError(
+        'Objects of type {type} not allowed'.format(type=type(obj))
+    )
 
 
 def b2o(obj: Any, b: bytes) -> Any:
@@ -705,7 +789,7 @@ def b2o(obj: Any, b: bytes) -> Any:
         shape, name, offset = x
         dtype = np.dtype(name)
         size = dtype.itemsize * np.prod(shape).astype(int)
-        a = np.frombuffer(b[offset:offset + size], dtype)
+        a = np.frombuffer(b[offset : offset + size], dtype)
         a.shape = shape
         if not np.little_endian:
             a = a.byteswap()
