@@ -1,3 +1,5 @@
+# fmt: off
+
 import warnings
 
 import numpy as np
@@ -413,7 +415,7 @@ def calculate_eos(atoms, npoints=5, eps=0.04, trajectory=None, callback=None):
 class CLICommand:
     """Calculate EOS from one or more trajectory files.
 
-    See https://wiki.fysik.dtu.dk/ase/tutorials/eos/eos.html for
+    See https://ase-lib.org/tutorials/eos/eos.html for
     more information.
     """
 
