@@ -1,4 +1,7 @@
+# fmt: off
+
 """Filters"""
+from functools import cached_property
 from itertools import product
 from warnings import warn
 
@@ -6,7 +9,7 @@ import numpy as np
 
 from ase.calculators.calculator import PropertyNotImplementedError
 from ase.stress import full_3x3_to_voigt_6_stress, voigt_6_to_full_3x3_stress
-from ase.utils import deprecated, lazyproperty
+from ase.utils import deprecated
 from ase.utils.abc import Optimizable
 
 __all__ = [
@@ -19,16 +22,16 @@ class OptimizableFilter(Optimizable):
     def __init__(self, filterobj):
         self.filterobj = filterobj
 
-    def get_positions(self):
-        return self.filterobj.get_positions()
+    def get_x(self):
+        return self.filterobj.get_positions().ravel()
 
-    def set_positions(self, positions):
-        self.filterobj.set_positions(positions)
+    def set_x(self, x):
+        self.filterobj.set_positions(x.reshape(-1, 3))
 
-    def get_forces(self):
-        return self.filterobj.get_forces()
+    def get_gradient(self):
+        return self.filterobj.get_forces().ravel()
 
-    @lazyproperty
+    @cached_property
     def _use_force_consistent_energy(self):
         # This boolean is in principle invalidated if the
         # calculator changes.  This can lead to weird things
@@ -40,13 +43,13 @@ class OptimizableFilter(Optimizable):
         else:
             return True
 
-    def get_potential_energy(self):
+    def get_value(self):
         force_consistent = self._use_force_consistent_energy
         return self.filterobj.get_potential_energy(
             force_consistent=force_consistent)
 
-    def __len__(self):
-        return len(self.filterobj)
+    def ndofs(self):
+        return 3 * len(self.filterobj)
 
     def iterimages(self):
         return self.filterobj.iterimages()
@@ -421,17 +424,20 @@ class UnitCellFilter(Filter):
         natoms = len(self.atoms)
         new_atom_positions = new[:natoms]
         new_deform_grad = new[natoms:] / self.cell_factor
+        deform = (new_deform_grad - np.eye(3)).T * self.mask
         # Set the new cell from the original cell and the new
         # deformation gradient.  Both current and final structures should
         # preserve symmetry, so if set_cell() calls FixSymmetry.adjust_cell(),
         # it should be OK
-        self.atoms.set_cell(self.orig_cell @ new_deform_grad.T,
+        newcell = self.orig_cell @ (np.eye(3) + deform)
+
+        self.atoms.set_cell(newcell,
                             scale_atoms=True)
         # Set the positions from the ones passed in (which are without the
         # deformation gradient applied) and the new deformation gradient.
         # This should also preserve symmetry, so if set_positions() calls
         # FixSymmetyr.adjust_positions(), it should be OK
-        self.atoms.set_positions(new_atom_positions @ new_deform_grad.T,
+        self.atoms.set_positions(new_atom_positions @ (np.eye(3) + deform),
                                  **kwargs)
 
     def get_potential_energy(self, force_consistent=True):
