@@ -1,3 +1,5 @@
+# fmt: off
+
 from os import unlink
 
 import numpy as np
@@ -16,8 +18,7 @@ class Render:
 
     def __init__(self, gui):
         self.gui = gui
-        self.win = win = ui.Window(
-            _('Render current view in povray ... '), wmtype='utility')
+        self.win = win = ui.Window(_('Render current view in povray ... '))
         win.add(ui.Label(_("Rendering %d atoms.") % len(self.gui.atoms)))
 
         guiwidth, guiheight = self.get_guisize()
