@@ -1,3 +1,5 @@
+# fmt: off
+
 import ase.gui.ui as ui
 from ase.gui.i18n import _
 from ase.utils import irotate, rotate
@@ -8,7 +10,7 @@ class Rotate:
 
     def __init__(self, gui):
         self.gui = gui
-        win = ui.Window(_('Rotate'), wmtype='utility')
+        win = ui.Window(_('Rotate'))
         win.add(_('Rotation angles:'))
         self.rotate = [ui.SpinBox(42.0, -360, 360, 1, self.change)
                        for _ in '123']
