@@ -1,3 +1,5 @@
+# fmt: off
+
 """Dialog for saving one or more configurations."""
 
 import numpy as np
@@ -25,12 +27,6 @@ last image. Examples: "name@-1": last image,
 
 def save_dialog(gui, filename=None):
     dialog = ui.SaveFileDialog(gui.window.win, _('Save ...'))
-    # fix tkinter not automatically setting dialog type
-    # remove from Python3.8+
-    # see https://github.com/python/cpython/pull/25187
-    # and https://bugs.python.org/issue43655
-    # and https://github.com/python/cpython/pull/25592
-    ui.set_windowtype(dialog.top, 'dialog')
     ui.Text(text).pack(dialog.top)
     filename = filename or dialog.go()
     if not filename:
