@@ -1,3 +1,5 @@
+# fmt: off
+
 """
 Extended XYZ support
 
@@ -16,6 +18,7 @@ from io import StringIO, UnsupportedOperation
 import numpy as np
 
 from ase.atoms import Atoms
+from ase.calculators.calculator import all_properties
 from ase.calculators.singlepoint import SinglePointCalculator
 from ase.constraints import FixAtoms, FixCartesian
 from ase.io.formats import index2range
@@ -45,10 +48,14 @@ UNPROCESSED_KEYS = {'uid'}
 
 SPECIAL_3_3_KEYS = {'Lattice', 'virial', 'stress'}
 
-# 'per-atom' and 'per-config'
+# Determine 'per-atom' and 'per-config' based on all_outputs shape,
+# but filter for things in all_properties because that's what
+# SinglePointCalculator accepts
 per_atom_properties = []
 per_config_properties = []
 for key, val in all_outputs.items():
+    if key not in all_properties:
+        continue
     if isinstance(val, ArrayProperty) and val.shapespec[0] == 'natoms':
         per_atom_properties.append(key)
     else:
@@ -502,9 +509,10 @@ def set_calc_and_arrays(atoms, arrays):
     results = {}
 
     for name, array in arrays.items():
-        if name in all_outputs:
+        if name in all_properties:
             results[name] = array
         else:
+            # store non-standard items in atoms.arrays
             atoms.new_array(name, array)
 
     for key in list(atoms.info):
@@ -830,7 +838,7 @@ def write_xyz(fileobj, images, comment='', columns=None,
                     voigt_6_to_full_3x3_stress(atoms.info['stress'])
 
         if columns is None:
-            fr_cols = (['symbols', 'positions']
+            fr_cols = (['symbols', 'positions', 'move_mask']
                        + [key for key in atoms.arrays if
                           key not in ['symbols', 'positions', 'numbers',
                                       'species', 'pos']])
@@ -885,7 +893,7 @@ def write_xyz(fileobj, images, comment='', columns=None,
 
         # Move mask
         if 'move_mask' in fr_cols:
-            cnstr = images[0]._get_constraints()
+            cnstr = images[0].constraints
             if len(cnstr) > 0:
                 c0 = cnstr[0]
                 if isinstance(c0, FixAtoms):
