@@ -1,3 +1,5 @@
+# fmt: off
+
 """File formats.
 
 This module implements the read(), iread() and write() functions in ase.io.
@@ -23,12 +25,12 @@ import sys
 import warnings
 from importlib import import_module
 from importlib.metadata import entry_points
-from pathlib import Path, PurePath
+from pathlib import PurePath
 from typing import (
     IO,
     Any,
     Dict,
-    Iterable,
+    Iterator,
     List,
     Optional,
     Sequence,
@@ -66,27 +68,6 @@ class IOFormat:
         self.magic: List[str] = []
         self.magic_regex: Optional[bytes] = None
 
-    def open(self, fname, mode: str = 'r') -> IO:
-        # We might want append mode, too
-        # We can allow more flags as needed (buffering etc.)
-        if mode not in list('rwa'):
-            raise ValueError("Only modes allowed are 'r', 'w', and 'a'")
-        if mode == 'r' and not self.can_read:
-            raise NotImplementedError('No reader implemented for {} format'
-                                      .format(self.name))
-        if mode == 'w' and not self.can_write:
-            raise NotImplementedError('No writer implemented for {} format'
-                                      .format(self.name))
-        if mode == 'a' and not self.can_append:
-            raise NotImplementedError('Appending not supported by {} format'
-                                      .format(self.name))
-
-        if self.isbinary:
-            mode += 'b'
-
-        path = Path(fname)
-        return path.open(mode, encoding=self.encoding)
-
     def _buf_as_filelike(self, data: Union[str, bytes]) -> IO:
         encoding = self.encoding
         if encoding is None:
@@ -359,6 +340,8 @@ F('aims', 'FHI-aims geometry file', '1S', ext='in')
 F('aims-output', 'FHI-aims output', '+S',
   module='aims', magic=b'*Invoking FHI-aims ...')
 F('bundletrajectory', 'ASE bundle trajectory', '+S')
+# XXX: Define plugin in ase db backends package:
+# F('aselmdb', 'ASE LMDB format', '+F')
 F('castep-castep', 'CASTEP output file', '+F',
   module='castep', ext='castep')
 F('castep-cell', 'CASTEP geom file', '1F',
@@ -469,6 +452,8 @@ F('onetep-in', 'ONETEP input file', '1F',
   magic=[b'*lock species ',
          b'*LOCK SPECIES ',
          b'*--- INPUT FILE ---*'])
+F('orca-output', 'ORCA output', '+F',
+  module='orca', magic=b'* O   R   C   A *')
 F('proteindatabank', 'Protein Data Bank', '+F',
   ext='pdb')
 F('png', 'Portable Network Graphics', '1B')
@@ -817,7 +802,7 @@ def iread(
         parallel: bool = True,
         do_not_split_by_at_sign: bool = False,
         **kwargs
-) -> Iterable[Atoms]:
+) -> Iterator[Atoms]:
     """Iterator for reading Atoms objects from file.
 
     Works as the `read` function, but yields one Atoms object at a time
@@ -949,6 +934,9 @@ def filetype(
         if filename.startswith('mysql') or filename.startswith('mariadb'):
             return 'mysql'
 
+        if filename.endswith('aselmdb'):
+            return 'db'
+
         # strip any compression extensions that can be read
         root, _compression = get_compression(filename)
         basename = os.path.basename(root)
