@@ -1,3 +1,5 @@
+# fmt: off
+
 import gzip
 import struct
 from collections import deque
@@ -8,8 +10,8 @@ import numpy as np
 from ase.atoms import Atoms
 from ase.calculators.lammps import convert
 from ase.calculators.singlepoint import SinglePointCalculator
+from ase.data import atomic_masses, chemical_symbols
 from ase.parallel import paropen
-from ase.quaternions import Quaternions
 
 
 def read_lammps_dump(infileobj, **kwargs):
@@ -102,6 +104,12 @@ def lammps_data_to_ase_atoms(
     if "element" in colnames:
         # priority to elements written in file
         elements = data[:, colnames.index("element")]
+    elif "mass" in colnames:
+        # try to determine elements from masses
+        elements = [
+            _mass2element(m)
+            for m in data[:, colnames.index("mass")].astype(float)
+        ]
     elif "type" in colnames:
         # fall back to `types` otherwise
         elements = data[:, colnames.index("type")].astype(int)
@@ -158,14 +166,14 @@ def lammps_data_to_ase_atoms(
         cell = prismobj.update_cell(cell)
 
     if quaternions is not None:
-        out_atoms = Quaternions(
+        out_atoms = atomsobj(
             symbols=elements,
             positions=positions,
             cell=cell,
             celldisp=celldisp,
             pbc=pbc,
-            quaternions=quaternions,
         )
+        out_atoms.new_array('quaternions', quaternions, dtype=float)
     elif positions is not None:
         # reverse coordinations transform to lammps system
         # (for all vectors = pos, vel, force)
@@ -207,12 +215,18 @@ def lammps_data_to_ase_atoms(
     # process the extra columns of fixes, variables and computes
     #    that can be dumped, add as additional arrays to atoms object
     for colname in colnames:
-        # determine if it is a compute or fix (but not the quaternian)
+        # determine if it is a compute, fix or
+        # custom property/atom (but not the quaternian)
         if (colname.startswith('f_') or colname.startswith('v_') or
-                (colname.startswith('c_') and not colname.startswith('c_q['))):
+            colname.startswith('d_') or colname.startswith('d2_') or
+            (colname.startswith('c_') and not colname.startswith('c_q['))):
             out_atoms.new_array(colname, get_quantity([colname]),
                                 dtype='float')
 
+        elif colname.startswith('i_') or colname.startswith('i2_'):
+            out_atoms.new_array(colname, get_quantity([colname]),
+                                dtype='int')
+
     return out_atoms
 
 
@@ -264,16 +278,16 @@ def read_lammps_dump_text(fileobj, index=-1, **kwargs):
     images = []
 
     # avoid references before assignment in case of incorrect file structure
-    cell, celldisp, pbc = None, None, False
+    cell, celldisp, pbc, info = None, None, False, {}
 
     while len(lines) > n_atoms:
         line = lines.popleft()
 
         if "ITEM: TIMESTEP" in line:
-            n_atoms = 0
             line = lines.popleft()
             # !TODO: pyflakes complains about this line -> do something
-            # ntimestep = int(line.split()[0])  # NOQA
+            ntimestep = int(line.split()[0])  # NOQA
+            info["timestep"] = ntimestep
 
         if "ITEM: NUMBER OF ATOMS" in line:
             line = lines.popleft()
@@ -323,8 +337,9 @@ def read_lammps_dump_text(fileobj, index=-1, **kwargs):
                 celldisp=celldisp,
                 atomsobj=Atoms,
                 pbc=pbc,
-                **kwargs
+                **kwargs,
             )
+            out_atoms.info.update(info)
             images.append(out_atoms)
 
         if len(images) > index_end >= 0:
@@ -479,3 +494,15 @@ def read_lammps_dump_binary(
             break
 
     return images[index]
+
+
+def _mass2element(mass):
+    """
+    Guess the element corresponding to a given atomic mass.
+
+    :param mass: Atomic mass for searching.
+    :return: Element symbol as a string.
+    """
+    min_idx = np.argmin(np.abs(atomic_masses - mass))
+    element = chemical_symbols[min_idx]
+    return element
