@@ -1,8 +1,12 @@
+# fmt: off
+
 """
 This module contains functionality for reading and writing an ASE
 Atoms object in VASP POSCAR format.
 
 """
+from __future__ import annotations
+
 import re
 from pathlib import Path
 from typing import List, Optional, TextIO, Tuple
@@ -15,6 +19,7 @@ from ase.io import ParseError
 from ase.io.formats import string2index
 from ase.io.utils import ImageIterator
 from ase.symbols import Symbols
+from ase.units import Ang, fs
 from ase.utils import reader, writer
 
 from .vasp_parsers import vasp_outcar_parsers as vop
@@ -140,17 +145,27 @@ def get_atomtypes_from_formula(formula):
 
 
 @reader
-def read_vasp(filename='CONTCAR'):
+def read_vasp(fd):
     """Import POSCAR/CONTCAR type file.
 
     Reads unitcell, atom positions and constraints from the POSCAR/CONTCAR
     file and tries to read atom types from POSCAR/CONTCAR header, if this
     fails the atom types are read from OUTCAR or POTCAR file.
     """
+    atoms = read_vasp_configuration(fd)
+    velocity_init_line = fd.readline()
+    if velocity_init_line.strip() and velocity_init_line[0].lower() == 'l':
+        read_lattice_velocities(fd)
+    velocities = read_velocities_if_present(fd, len(atoms))
+    if velocities is not None:
+        atoms.set_velocities(velocities)
+    return atoms
 
+
+def read_vasp_configuration(fd):
+    """Read common POSCAR/CONTCAR/CHGCAR/CHG quantities and return Atoms."""
     from ase.data import chemical_symbols
 
-    fd = filename
     # The first line is in principle a comment line, however in VASP
     # 4.x a common convention is to have it contain the atom symbols,
     # eg. "Ag Ge" in the same order as later in the file (and POTCAR
@@ -249,6 +264,7 @@ def read_vasp(filename='CONTCAR'):
         atoms_pos[atom] = [float(_) for _ in ac[0:3]]
         if selective_dynamics:
             selective_flags[atom] = [_ == 'F' for _ in ac[3:6]]
+
     atoms = Atoms(symbols=atom_symbols, cell=cell, pbc=True)
     if cartesian:
         atoms_pos *= scale
@@ -257,9 +273,41 @@ def read_vasp(filename='CONTCAR'):
         atoms.set_scaled_positions(atoms_pos)
     if selective_dynamics:
         set_constraints(atoms, selective_flags)
+
     return atoms
 
 
+def read_lattice_velocities(fd):
+    """
+    Read lattice velocities and vectors from POSCAR/CONTCAR.
+    As lattice velocities are not yet implemented in ASE, this function just
+    throws away these lines.
+    """
+    fd.readline()  # initialization state
+    for _ in range(3):  # lattice velocities
+        fd.readline()
+    for _ in range(3):  # lattice vectors
+        fd.readline()
+    fd.readline()  # get rid of 1 empty line below if it exists
+
+
+def read_velocities_if_present(fd, natoms) -> np.ndarray | None:
+    """Read velocities from POSCAR/CONTCAR if present, return in ASE units."""
+    # Check if it is the velocities block or the MD extra block
+    words = fd.readline().split()
+    if len(words) <= 1:  # MD extra block or end of file
+        return None
+    atoms_vel = np.empty((natoms, 3))
+    atoms_vel[0] = (float(words[0]), float(words[1]), float(words[2]))
+    for atom in range(1, natoms):
+        words = fd.readline().split()
+        assert len(words) == 3
+        atoms_vel[atom] = (float(words[0]), float(words[1]), float(words[2]))
+
+    # unit conversion from Angstrom/fs to ASE units
+    return atoms_vel * (Ang / fs)
+
+
 def set_constraints(atoms: Atoms, selective_flags: np.ndarray):
     """Set constraints based on selective_flags"""
     from ase.constraints import FixAtoms, FixConstraint, FixScaled
@@ -428,7 +476,7 @@ def read_vasp_xml(filename='vasprun.xml', index=-1):
                         kpts_params = OrderedDict()
                         parameters['kpoints_generation'] = kpts_params
                         for par in subelem.iter():
-                            if par.tag in ['v', 'i']:
+                            if par.tag in ['v', 'i'] and "name" in par.attrib:
                                 parname = par.attrib['name'].lower()
                                 kpts_params[parname] = __get_xml_parameter(par)
 
@@ -846,6 +894,15 @@ def write_vasp(
             fd.write(''.join([f'{f:>4s}' for f in flags]))
         fd.write('\n')
 
+    # if velocities in atoms object write velocities
+    if atoms.has('momenta'):
+        cform = 3 * ' {:19.16f}' + '\n'
+        fd.write('Cartesian\n')
+        # unit conversion to Angstrom / fs
+        vel = atoms.get_velocities() / (Ang / fs)
+        for vatom in vel:
+            fd.write(cform.format(*vatom))
+
 
 def _handle_ase_constraints(atoms: Atoms) -> np.ndarray:
     """Convert the ASE constraints on `atoms` to VASP constraints
@@ -875,7 +932,7 @@ def _handle_ase_constraints(atoms: Atoms) -> np.ndarray:
             mask = np.all(
                 np.abs(np.cross(constr.dir, atoms.cell)) < 1e-5, axis=1
             )
-            if sum(mask) != 1:
+            if mask.sum() != 1:
                 raise RuntimeError(
                     'VASP requires that the direction of FixedPlane '
                     'constraints is parallel with one of the cell axis'
@@ -886,7 +943,7 @@ def _handle_ase_constraints(atoms: Atoms) -> np.ndarray:
             mask = np.all(
                 np.abs(np.cross(constr.dir, atoms.cell)) < 1e-5, axis=1
             )
-            if sum(mask) != 1:
+            if mask.sum() != 1:
                 raise RuntimeError(
                     'VASP requires that the direction of FixedLine '
                     'constraints is parallel with one of the cell axis'
