@@ -1,11 +1,11 @@
 """Andersen dynamics class."""
-from typing import IO, Optional, Union
+
+import warnings
 
 from numpy import cos, log, ones, pi, random, repeat
 
 from ase import Atoms, units
 from ase.md.md import MolecularDynamics
-from ase.parallel import DummyMPI, world
 
 
 class Andersen(MolecularDynamics):
@@ -18,16 +18,12 @@ class Andersen(MolecularDynamics):
         temperature_K: float,
         andersen_prob: float,
         fixcm: bool = True,
-        trajectory: Optional[str] = None,
-        logfile: Optional[Union[IO, str]] = None,
-        loginterval: int = 1,
-        communicator=world,
         rng=random,
-        append_trajectory: bool = False,
+        **kwargs,
     ):
-        """"
-        Parameters:
-
+        """
+        Parameters
+        ----------
         atoms: Atoms object
             The list of atoms.
 
@@ -49,24 +45,9 @@ class Andersen(MolecularDynamics):
             Random number generator. This must have the ``random`` method
             with the same signature as ``numpy.random.random``.
 
-        logfile: file object or str (optional)
-            If *logfile* is a string, a file with that name will be opened.
-            Use '-' for stdout.
-
-        trajectory: Trajectory object or str (optional)
-            Attach trajectory object. If *trajectory* is a string a
-            Trajectory will be constructed. Use *None* (the default) for no
-            trajectory.
-
-        communicator: MPI communicator (optional)
-            Communicator used to distribute random numbers to all tasks.
-            Default: ase.parallel.world. Set to None to disable communication.
-
-        append_trajectory: bool (optional)
-            Defaults to False, which causes the trajectory file to be
-            overwritten each time the dynamics is restarted from scratch.
-            If True, the new structures are appended to the trajectory
-            file instead.
+        **kwargs : dict, optional
+            Additional arguments passed to :class:~ase.md.md.MolecularDynamics
+            base class.
 
         The temperature is imposed by stochastic collisions with a heat bath
         that acts on velocity components of randomly chosen particles.
@@ -75,16 +56,18 @@ class Andersen(MolecularDynamics):
 
         H. C. Andersen, J. Chem. Phys. 72 (4), 2384–2393 (1980)
         """
+        if 'communicator' in kwargs:
+            msg = (
+                '`communicator` has been deprecated since ASE 3.25.0 '
+                'and will be removed in ASE 3.26.0. Use `comm` instead.'
+            )
+            warnings.warn(msg, FutureWarning)
+            kwargs['comm'] = kwargs.pop('communicator')
         self.temp = units.kB * temperature_K
         self.andersen_prob = andersen_prob
         self.fix_com = fixcm
         self.rng = rng
-        if communicator is None:
-            communicator = DummyMPI()
-        self.communicator = communicator
-        MolecularDynamics.__init__(self, atoms, timestep, trajectory,
-                                   logfile, loginterval,
-                                   append_trajectory=append_trajectory)
+        MolecularDynamics.__init__(self, atoms, timestep, **kwargs)
 
     def set_temperature(self, temperature_K):
         self.temp = units.kB * temperature_K
@@ -98,13 +81,13 @@ class Andersen(MolecularDynamics):
     def boltzmann_random(self, width, size):
         x = self.rng.random(size=size)
         y = self.rng.random(size=size)
-        z = width * cos(2 * pi * x) * (-2 * log(1 - y))**0.5
+        z = width * cos(2 * pi * x) * (-2 * log(1 - y)) ** 0.5
         return z
 
     def get_maxwell_boltzmann_velocities(self):
         natoms = len(self.atoms)
         masses = repeat(self.masses, 3).reshape(natoms, 3)
-        width = (self.temp / masses)**0.5
+        width = (self.temp / masses) ** 0.5
         velos = self.boltzmann_random(width, size=(natoms, 3))
         return velos  # [[x, y, z],] components for each atom
 
@@ -124,10 +107,11 @@ class Andersen(MolecularDynamics):
 
         if self.fix_com:
             # add random velocity to center of mass to prepare Andersen
-            width = (self.temp / sum(self.masses))**0.5
-            self.random_com_velocity = (ones(self.v.shape)
-                                        * self.boltzmann_random(width, (3)))
-            self.communicator.broadcast(self.random_com_velocity, 0)
+            width = (self.temp / sum(self.masses)) ** 0.5
+            self.random_com_velocity = ones(
+                self.v.shape
+            ) * self.boltzmann_random(width, (3))
+            self.comm.broadcast(self.random_com_velocity, 0)
             self.v += self.random_com_velocity
 
         self.v += 0.5 * forces / self.masses * self.dt
@@ -135,10 +119,11 @@ class Andersen(MolecularDynamics):
         # apply Andersen thermostat
         self.random_velocity = self.get_maxwell_boltzmann_velocities()
         self.andersen_chance = self.rng.random(size=self.v.shape)
-        self.communicator.broadcast(self.random_velocity, 0)
-        self.communicator.broadcast(self.andersen_chance, 0)
-        self.v[self.andersen_chance <= self.andersen_prob] \
-            = self.random_velocity[self.andersen_chance <= self.andersen_prob]
+        self.comm.broadcast(self.random_velocity, 0)
+        self.comm.broadcast(self.andersen_chance, 0)
+        self.v[self.andersen_chance <= self.andersen_prob] = (
+            self.random_velocity[self.andersen_chance <= self.andersen_prob]
+        )
 
         x = atoms.get_positions()
         if self.fix_com:
