@@ -1,3 +1,5 @@
+# fmt: off
+
 from typing import IO, Optional, Union
 
 import numpy as np
@@ -209,7 +211,7 @@ class ContourExploration(Dynamics):
         """ Call Dynamics.run and adjust max_steps """
         return Dynamics.run(self, steps=steps)
 
-    def log(self):
+    def log(self, gradient):
         if self.logfile is not None:
             # name = self.__class__.__name__
             if self.nsteps == 0:
@@ -238,7 +240,7 @@ class ContourExploration(Dynamics):
 
     def rand_vect(self):
         '''Returns a random (Natoms,3) vector'''
-        vect = self.rng.random((len(self._actual_atoms), 3)) - 0.5
+        vect = self.rng.normal(size=(len(self._actual_atoms), 3))
         return vect
 
     def create_drift_unit_vector(self, N, T):
