@@ -1,4 +1,7 @@
+# fmt: off
+
 import warnings
+from pathlib import Path
 from typing import IO, Optional, Union
 
 import numpy as np
@@ -16,8 +19,8 @@ class BFGS(Optimizer):
         self,
         atoms: Atoms,
         restart: Optional[str] = None,
-        logfile: Optional[Union[IO, str]] = '-',
-        trajectory: Optional[str] = None,
+        logfile: Optional[Union[IO, str, Path]] = '-',
+        trajectory: Optional[Union[str, Path]] = None,
         append_trajectory: bool = False,
         maxstep: Optional[float] = None,
         alpha: Optional[float] = None,
@@ -35,10 +38,10 @@ class BFGS(Optimizer):
             such a name will be searched and hessian matrix stored will
             be used, if the file exists.
 
-        trajectory: str
+        trajectory: str or Path
             Trajectory file used to store optimisation path.
 
-        logfile: file object or str
+        logfile: file object, Path, or str
             If *logfile* is a string, a file with that name will be opened.
             Use '-' for stdout.
 
@@ -76,7 +79,7 @@ class BFGS(Optimizer):
 
     def initialize(self):
         # initial hessian
-        self.H0 = np.eye(3 * len(self.optimizable)) * self.alpha
+        self.H0 = np.eye(self.optimizable.ndofs()) * self.alpha
 
         self.H = None
         self.pos0 = None
@@ -90,25 +93,26 @@ class BFGS(Optimizer):
         else:
             self.H, self.pos0, self.forces0, self.maxstep = file
 
-    def step(self, forces=None):
+    def step(self, gradient=None):
         optimizable = self.optimizable
 
-        if forces is None:
-            forces = optimizable.get_forces()
+        if gradient is None:
+            gradient = optimizable.get_gradient()
 
-        pos = optimizable.get_positions()
-        dpos, steplengths = self.prepare_step(pos, forces)
+        pos = optimizable.get_x()
+        dpos, steplengths = self.prepare_step(pos, gradient)
         dpos = self.determine_step(dpos, steplengths)
-        optimizable.set_positions(pos + dpos)
+        optimizable.set_x(pos + dpos)
         if isinstance(self.atoms, UnitCellFilter):
             self.dump((self.H, self.pos0, self.forces0, self.maxstep,
                        self.atoms.orig_cell))
         else:
             self.dump((self.H, self.pos0, self.forces0, self.maxstep))
 
-    def prepare_step(self, pos, forces):
-        forces = forces.reshape(-1)
-        self.update(pos.flat, forces, self.pos0, self.forces0)
+    def prepare_step(self, pos, gradient):
+        pos = pos.ravel()
+        gradient = gradient.ravel()
+        self.update(pos, gradient, self.pos0, self.forces0)
         omega, V = eigh(self.H)
 
         # FUTURE: Log this properly
@@ -123,10 +127,12 @@ class BFGS(Optimizer):
         #         self.logfile.write(msg)
         #         self.logfile.flush()
 
-        dpos = np.dot(V, np.dot(forces, V) / np.fabs(omega)).reshape((-1, 3))
-        steplengths = (dpos**2).sum(1)**0.5
-        self.pos0 = pos.flat.copy()
-        self.forces0 = forces.copy()
+        dpos = np.dot(V, np.dot(gradient, V) / np.fabs(omega))
+        # XXX Here we are calling gradient_norm() on some positions.
+        # Should there be a general norm concept
+        steplengths = self.optimizable.gradient_norm(dpos)
+        self.pos0 = pos
+        self.forces0 = gradient.copy()
         return dpos, steplengths
 
     def determine_step(self, dpos, steplengths):
