@@ -1,3 +1,5 @@
+# fmt: off
+
 # ******NOTICE***************
 # optimize.py module by Travis E. Oliphant
 #
@@ -9,7 +11,7 @@ import time
 from typing import IO, Optional, Union
 
 import numpy as np
-from numpy import absolute, eye, isinf, sqrt
+from numpy import absolute, eye, isinf
 
 from ase import Atoms
 from ase.optimize.optimize import Optimizer
@@ -107,13 +109,9 @@ class BFGSLineSearch(Optimizer):
         optimizable = self.optimizable
 
         if forces is None:
-            forces = optimizable.get_forces()
+            forces = optimizable.get_gradient().reshape(-1, 3)
 
-        if optimizable.is_neb():
-            raise TypeError('NEB calculations cannot use the BFGSLineSearch'
-                            ' optimizer. Use BFGS or another optimizer.')
-        r = optimizable.get_positions()
-        r = r.reshape(-1)
+        r = optimizable.get_x()
         g = -forces.reshape(-1) / self.alpha
         p0 = self.p
         self.update(r, g, self.r0, self.g0, p0)
@@ -122,8 +120,8 @@ class BFGSLineSearch(Optimizer):
 
         self.p = -np.dot(self.H, g)
         p_size = np.sqrt((self.p**2).sum())
-        if p_size <= np.sqrt(len(optimizable) * 1e-10):
-            self.p /= (p_size / np.sqrt(len(optimizable) * 1e-10))
+        if p_size <= np.sqrt(optimizable.ndofs() / 3 * 1e-10):
+            self.p /= (p_size / np.sqrt(optimizable.ndofs() / 3 * 1e-10))
         ls = LineSearch()
         self.alpha_k, e, self.e0, self.no_update = \
             ls._line_search(self.func, self.fprime, r, self.p, g, e, self.e0,
@@ -133,15 +131,15 @@ class BFGSLineSearch(Optimizer):
             raise RuntimeError("LineSearch failed!")
 
         dr = self.alpha_k * self.p
-        optimizable.set_positions((r + dr).reshape(len(optimizable), -1))
+        optimizable.set_x(r + dr)
         self.r0 = r
         self.g0 = g
         self.dump((self.r0, self.g0, self.e0, self.task, self.H))
 
     def update(self, r, g, r0, g0, p0):
-        self.I = eye(len(self.optimizable) * 3, dtype=int)
+        self.I = eye(self.optimizable.ndofs(), dtype=int)
         if self.H is None:
-            self.H = eye(3 * len(self.optimizable))
+            self.H = eye(self.optimizable.ndofs())
             # self.B = np.linalg.inv(self.H)
             return
         else:
@@ -172,18 +170,18 @@ class BFGSLineSearch(Optimizer):
 
     def func(self, x):
         """Objective function for use of the optimizers"""
-        self.optimizable.set_positions(x.reshape(-1, 3))
+        self.optimizable.set_x(x)
         self.function_calls += 1
         # Scale the problem as SciPy uses I as initial Hessian.
-        return self.optimizable.get_potential_energy() / self.alpha
+        return self.optimizable.get_value() / self.alpha
 
     def fprime(self, x):
         """Gradient of the objective function for use of the optimizers"""
-        self.optimizable.set_positions(x.reshape(-1, 3))
+        self.optimizable.set_x(x)
         self.force_calls += 1
         # Remember that forces are minus the gradient!
         # Scale the problem as SciPy uses I as initial Hessian.
-        forces = self.optimizable.get_forces().reshape(-1)
+        forces = self.optimizable.get_gradient()
         return - forces / self.alpha
 
     def replay_trajectory(self, traj):
@@ -208,13 +206,11 @@ class BFGSLineSearch(Optimizer):
             self.r0 = r0
             self.g0 = g0
 
-    def log(self, forces=None):
+    def log(self, gradient):
         if self.logfile is None:
             return
-        if forces is None:
-            forces = self.optimizable.get_forces()
-        fmax = sqrt((forces**2).sum(axis=1).max())
-        e = self.optimizable.get_potential_energy()
+        fmax = self.optimizable.gradient_norm(gradient)
+        e = self.optimizable.get_value()
         T = time.localtime()
         name = self.__class__.__name__
         w = self.logfile.write
