@@ -1,3 +1,5 @@
+# fmt: off
+
 from typing import IO, Any, Dict, List, Optional, Type, Union
 
 from numpy.linalg import norm
@@ -120,6 +122,9 @@ class BFGSClimbFixInternals(BFGS):
         self.autolog = 'logfile' not in self.optB_kwargs
         self.autotraj = 'trajectory' not in self.optB_kwargs
 
+    def Nx3(self, array):
+        return array.reshape(-1, 3)
+
     def read(self):
         (self.H, self.pos0, self.forces0, self.maxstep,
          self.targetvalue) = self.load()
@@ -136,18 +141,19 @@ class BFGSClimbFixInternals(BFGS):
     def pretend2climb(self):
         """Get directions for climbing and climb with optimizer 'A'."""
         proj_forces = self.get_projected_forces()
-        pos = self.optimizable.get_positions()
+        pos = self.optimizable.get_x()
         dpos, steplengths = self.prepare_step(pos, proj_forces)
         dpos = self.determine_step(dpos, steplengths)
         return pos, dpos
 
     def update_positions_and_targetvalue(self, pos, dpos):
         """Adjust constrained targetvalue of constraint and update positions."""
-        self.constr2climb.adjust_positions(pos, pos + dpos)  # update sigma
+        self.constr2climb.adjust_positions(
+            self.Nx3(pos), self.Nx3(pos + dpos))  # update sigma
         self.targetvalue += self.constr2climb.sigma          # climb constraint
         self.constr2climb.targetvalue = self.targetvalue     # adjust positions
-        self.optimizable.set_positions(
-            self.optimizable.get_positions())   # to targetvalue
+        # XXX very magical ...
+        self.optimizable.set_x(self.optimizable.get_x())   # to targetvalue
 
     def relax_remaining_dof(self):
         """Optimize remaining degrees of freedom with optimizer 'B'."""
@@ -158,7 +164,8 @@ class BFGSClimbFixInternals(BFGS):
         fmax = self.get_scaled_fmax()
         with self.optB(self.optimizable.atoms, **self.optB_kwargs) as opt:
             opt.run(fmax)  # optimize with scaled fmax
-            if self.converged() and fmax > self.optB_fmax:
+            grad = self.optimizable.get_gradient()
+            if self.converged(grad) and fmax > self.optB_fmax:
                 # (final) optimization with desired fmax
                 opt.run(self.optB_fmax)
 
@@ -172,21 +179,24 @@ class BFGSClimbFixInternals(BFGS):
         """Return the projected forces along the constrained coordinate in
         uphill direction (negative sign)."""
         forces = self.constr2climb.projected_forces
-        forces = -forces.reshape(self.optimizable.get_positions().shape)
+        # XXX simplify me once optimizable shape shenanigans have converged
+        forces = -forces.ravel()
         return forces
 
     def get_total_forces(self):
         """Return forces obeying all constraints plus projected forces."""
-        return self.optimizable.get_forces() + self.get_projected_forces()
+        forces = self.optimizable.get_gradient()
+        return forces + self.get_projected_forces()
 
-    def converged(self, forces=None):
+    def converged(self, gradient):
         """Did the optimization converge based on the total forces?"""
-        forces = forces or self.get_total_forces()
-        return super().converged(forces=forces)
+        # XXX ignoring gradient
+        gradient = self.get_total_forces().ravel()
+        return super().converged(gradient=gradient)
 
-    def log(self, forces=None):
-        forces = forces or self.get_total_forces()
-        super().log(forces=forces)
+    def log(self, gradient):
+        forces = self.get_total_forces()
+        super().log(gradient=forces.ravel())
 
 
 def get_fixinternals(atoms):
