@@ -1,3 +1,5 @@
+# fmt: off
+
 from typing import IO, Any, Callable, Dict, List, Optional, Union
 
 import numpy as np
@@ -163,18 +165,18 @@ class FIRE(Optimizer):
         optimizable = self.optimizable
 
         if f is None:
-            f = optimizable.get_forces()
+            f = optimizable.get_gradient().reshape(-1, 3)
 
         if self.v is None:
-            self.v = np.zeros((len(optimizable), 3))
+            self.v = np.zeros(optimizable.ndofs()).reshape(-1, 3)
             if self.downhill_check:
-                self.e_last = optimizable.get_potential_energy()
-                self.r_last = optimizable.get_positions().copy()
+                self.e_last = optimizable.get_value()
+                self.r_last = optimizable.get_x().reshape(-1, 3).copy()
                 self.v_last = self.v.copy()
         else:
             is_uphill = False
             if self.downhill_check:
-                e = optimizable.get_potential_energy()
+                e = optimizable.get_value()
                 # Check if the energy actually decreased
                 if e > self.e_last:
                     # If not, reset to old positions...
@@ -182,10 +184,10 @@ class FIRE(Optimizer):
                         self.position_reset_callback(
                             optimizable, self.r_last, e,
                             self.e_last)
-                    optimizable.set_positions(self.r_last)
+                    optimizable.set_x(self.r_last.ravel())
                     is_uphill = True
-                self.e_last = optimizable.get_potential_energy()
-                self.r_last = optimizable.get_positions().copy()
+                self.e_last = optimizable.get_value()
+                self.r_last = optimizable.get_x().reshape(-1, 3).copy()
                 self.v_last = self.v.copy()
 
             vf = np.vdot(f, self.v)
@@ -207,6 +209,6 @@ class FIRE(Optimizer):
         normdr = np.sqrt(np.vdot(dr, dr))
         if normdr > self.maxstep:
             dr = self.maxstep * dr / normdr
-        r = optimizable.get_positions()
-        optimizable.set_positions(r + dr)
+        r = optimizable.get_x().reshape(-1, 3)
+        optimizable.set_x((r + dr).ravel())
         self.dump((self.v, self.dt))
