@@ -1,3 +1,5 @@
+# fmt: off
+
 # Copyright (C) 2003  CAMP
 # Please see the accompanying LICENSE file for further information.
 
@@ -19,7 +21,9 @@ from ase.optimize.optimize import Optimizer
 
 def f(lamda, Gbar, b, radius):
     b1 = b - lamda
-    g = radius**2 - np.dot(Gbar / b1, Gbar / b1)
+    b1[abs(b1) < 1e-40] = 1e-40  # avoid divide-by-zero
+    gbar_b_lamda = Gbar / b1  # only compute once
+    g = radius**2 - np.dot(gbar_b_lamda, gbar_b_lamda)
     return g
 
 
@@ -74,8 +78,15 @@ def scale_radius_force(f, r):
 def find_lamda(upperlimit, Gbar, b, radius):
     lowerlimit = upperlimit
     step = 0.1
+    i = 0
+
     while f(lowerlimit, Gbar, b, radius) < 0:
         lowerlimit -= step
+        i += 1
+
+        # if many iterations are required, dynamically scale step for efficiency
+        if i % 100 == 0:
+            step *= 1.25
 
     converged = False
 
@@ -155,7 +166,7 @@ class GoodOldQuasiNewton(Optimizer):
         self.verbosity = verbosity
         self.diagonal = diagonal
 
-        n = len(self.optimizable) * 3
+        n = self.optimizable.ndofs()
         if radius is None:
             self.radius = 0.05 * np.sqrt(n) / 10.0
         else:
@@ -170,10 +181,6 @@ class GoodOldQuasiNewton(Optimizer):
         self.radius = max(min(self.radius, self.maxradius), 0.0001)
 
         self.transitionstate = transitionstate
-
-        if self.optimizable.is_neb():
-            self.forcemin = False
-
         self.t0 = time.time()
 
     def initialize(self):
@@ -194,7 +201,7 @@ class GoodOldQuasiNewton(Optimizer):
 
     def set_default_hessian(self):
         # set unit matrix
-        n = len(self.optimizable) * 3
+        n = self.optimizable.ndofs()
         hessian = np.zeros((n, n))
         for i in range(n):
             hessian[i][i] = self.diagonal
@@ -285,12 +292,12 @@ class GoodOldQuasiNewton(Optimizer):
         """
 
         if forces is None:
-            forces = self.optimizable.get_forces()
+            forces = self.optimizable.get_gradient().reshape(-1, 3)
 
-        pos = self.optimizable.get_positions().ravel()
-        G = -self.optimizable.get_forces().ravel()
+        pos = self.optimizable.get_x()
+        G = -self.optimizable.get_gradient()
 
-        energy = self.optimizable.get_potential_energy()
+        energy = self.optimizable.get_value()
 
         if hasattr(self, 'oldenergy'):
             self.write_log('energies ' + str(energy) +
@@ -306,7 +313,7 @@ class GoodOldQuasiNewton(Optimizer):
 
             if (energy - self.oldenergy) > de:
                 self.write_log('reject step')
-                self.optimizable.set_positions(self.oldpos.reshape((-1, 3)))
+                self.optimizable.set_x(self.oldpos)
                 G = self.oldG
                 energy = self.oldenergy
                 self.radius *= 0.5
@@ -356,7 +363,7 @@ class GoodOldQuasiNewton(Optimizer):
         for i in range(n):
             step += D[i] * V[i]
 
-        pos = self.optimizable.get_positions().ravel()
+        pos = self.optimizable.get_x()
         pos += step
 
         energy_estimate = self.get_energy_estimate(D, Gbar, b)
@@ -364,7 +371,7 @@ class GoodOldQuasiNewton(Optimizer):
         self.gbar_estimate = self.get_gbar_estimate(D, Gbar, b)
         self.old_gbar = Gbar
 
-        self.optimizable.set_positions(pos.reshape((-1, 3)))
+        self.optimizable.set_x(pos)
 
     def get_energy_estimate(self, D, Gbar, b):
 
