@@ -1,3 +1,5 @@
+# fmt: off
+
 from typing import IO, Optional, Union
 
 import numpy as np
@@ -71,17 +73,17 @@ class SciPyOptimizer(Optimizer):
 
         This class is mostly usable for subclasses wanting to redefine the
         parameters (and the objective function)"""
-        return self.optimizable.get_positions().reshape(-1)
+        return self.optimizable.get_x()
 
     def f(self, x):
         """Objective function for use of the optimizers"""
-        self.optimizable.set_positions(x.reshape(-1, 3))
+        self.optimizable.set_x(x)
         # Scale the problem as SciPy uses I as initial Hessian.
-        return self.optimizable.get_potential_energy() / self.H0
+        return self.optimizable.get_value() / self.H0
 
     def fprime(self, x):
         """Gradient of the objective function for use of the optimizers"""
-        self.optimizable.set_positions(x.reshape(-1, 3))
+        self.optimizable.set_x(x)
         self.force_calls += 1
 
         if self.callback_always:
@@ -89,7 +91,7 @@ class SciPyOptimizer(Optimizer):
 
         # Remember that forces are minus the gradient!
         # Scale the problem as SciPy uses I as initial Hessian.
-        return - self.optimizable.get_forces().reshape(-1) / self.H0
+        return -self.optimizable.get_gradient() / self.H0
 
     def callback(self, x):
         """Callback function to be run after each iteration by SciPy
@@ -104,10 +106,11 @@ class SciPyOptimizer(Optimizer):
         """
         if self.nsteps < self.max_steps:
             self.nsteps += 1
-        f = self.optimizable.get_forces()
+        gradient = self.optimizable.get_gradient()
+        f = gradient.reshape(-1, 3)
         self.log(f)
         self.call_observers()
-        if self.converged(f):
+        if self.converged(gradient):
             raise Converged
 
     def run(self, fmax=0.05, steps=100000000):
@@ -116,7 +119,8 @@ class SciPyOptimizer(Optimizer):
         try:
             # As SciPy does not log the zeroth iteration, we do that manually
             if self.nsteps == 0:
-                self.log()
+                gradient = self.optimizable.get_gradient()
+                self.log(gradient)
                 self.call_observers()
 
             self.max_steps = steps + self.nsteps
@@ -125,7 +129,8 @@ class SciPyOptimizer(Optimizer):
             self.call_fmin(fmax / self.H0, steps)
         except Converged:
             pass
-        return self.converged()
+        gradient = self.optimizable.get_gradient()
+        return self.converged(gradient)
 
     def dump(self, data):
         pass
@@ -242,14 +247,14 @@ class SciPyGradientlessOptimizer(Optimizer):
 
         This class is mostly usable for subclasses wanting to redefine the
         parameters (and the objective function)"""
-        return self.optimizable.get_positions().reshape(-1)
+        return self.optimizable.get_x().reshape(-1)
 
     def f(self, x):
         """Objective function for use of the optimizers"""
-        self.optimizable.set_positions(x.reshape(-1, 3))
+        self.optimizable.set_x(x)
         self.function_calls += 1
         # Scale the problem as SciPy uses I as initial Hessian.
-        return self.optimizable.get_potential_energy()
+        return self.optimizable.get_value()
 
     def callback(self, x):
         """Callback function to be run after each iteration by SciPy
@@ -259,7 +264,7 @@ class SciPyGradientlessOptimizer(Optimizer):
         call something similar before as well.
         """
         # We can't assume that forces are available!
-        # f = self.optimizable.get_forces()
+        # f = self.optimizable.get_gradient().reshape(-1, 3)
         # self.log(f)
         self.call_observers()
         # if self.converged(f):
