@@ -1,5 +1,8 @@
-from ase.spacegroup.crystal_data import (get_bravais_class, get_point_group,
-                                         polar_space_group)
+from ase.spacegroup.crystal_data import (
+    get_bravais_class,
+    get_point_group,
+    polar_space_group,
+)
 from ase.spacegroup.spacegroup import Spacegroup, get_spacegroup
 from ase.spacegroup.xtal import crystal
 
