@@ -1,3 +1,5 @@
+# fmt: off
+
 import collections
 from functools import reduce, singledispatch
 from typing import (
@@ -284,7 +286,8 @@ class DOSCollection(collections.abc.Sequence):
         matches = self._select_to_list(self, info_selection, negative=True)
         return type(self)(matches)
 
-    def sum_by(self, *info_keys: str) -> 'DOSCollection':
+    # Use typehint *info_keys: str from python3.11+
+    def sum_by(self, *info_keys) -> 'DOSCollection':
         """Return a DOSCollection with some data summed by common attributes
 
         For example, if ::
@@ -395,7 +398,9 @@ class GridDOSCollection(DOSCollection):
         else:
             self._energies = np.asarray(energies)
 
-        self._weights = np.empty((len(dos_list), len(self._energies)), float)
+        self._weights: np.ndarray = np.empty(
+            (len(dos_list), len(self._energies)), float,
+        )
         self._info = []
 
         for i, dos_data in enumerate(dos_list):
