@@ -1,3 +1,6 @@
+# fmt: off
+import numpy as np
+
 from ase import Atoms
 from ase.geometry import get_duplicate_atoms
 
@@ -19,12 +22,22 @@ def test_atoms_get_duplicates():
     get_duplicate_atoms(at, delete=True)
     assert len(at) == 4
 
+
+def test_no_duplicate_atoms():
+    """test if it works if no duplicates are detected."""
     at = Atoms('H3', positions=[[0., 0., 0.],
                                 [1., 0., 0.],
                                 [3, 2.2, 5.2]])
 
-    # test if it works if no duplicates are detected.
     get_duplicate_atoms(at, delete=True)
     dups = get_duplicate_atoms(at)
 
     assert dups.size == 0
+
+
+def test_pbc():
+    """test if it works under PBCs."""
+    positions = [[0.0, 0.0, 0.0], [0.0, 0.0, 0.9]]
+    atoms = Atoms('H2', positions=positions, cell=np.eye(3), pbc=True)
+    dups = get_duplicate_atoms(atoms, cutoff=0.2)
+    np.testing.assert_array_equal(dups, [[0, 1]])
