@@ -1,3 +1,4 @@
+# fmt: off
 import pytest
 
 from ase import io
@@ -11,13 +12,16 @@ from ase.build import molecule
 def test_no_spin_and_spin(factory):
     txt = 'out.txt'
 
-    calculator = factory.calc(mode='fd', h=0.3, txt=txt)
-    atoms = molecule('H2', calculator=calculator)
-    atoms.center(vacuum=3)
-    atoms.get_potential_energy()
-    atoms.set_initial_magnetic_moments([0.5, 0.5])
-    calculator.set(charge=1)
-    atoms.get_potential_energy()
+    with open(txt, 'w') as txt_fd:
+        calculator = factory.calc(mode='fd', h=0.3, txt=txt_fd)
+        atoms = molecule('H2', calculator=calculator)
+        atoms.center(vacuum=3)
+        atoms.get_potential_energy()
+        atoms.set_initial_magnetic_moments([0.5, 0.5])
+        calculator = calculator.new(charge=1, txt=txt_fd)
+        atoms.calc = calculator
+        # calculator.set(charge=1)
+        atoms.get_potential_energy()
 
     # read again
     t = io.read(txt, index=':')
