@@ -1,5 +1,4 @@
-import pickle
-
+# fmt: off
 import numpy as np
 
 from ase.cell import Cell
@@ -13,11 +12,7 @@ def test_o2b2o():
                ['a', 42, True, None, np.nan, np.inf, 1j],
                Cell(np.eye(3)),
                {'a': {'b': {'c': np.ones(3)}}}]:
-        p1 = pickle.dumps(o1)
         b1 = object_to_bytes(o1)
         o2 = bytes_to_object(b1)
-        p2 = pickle.dumps(o2)
         print(o2)
-        print(b1)
-        print()
-        assert p1 == p2, (o1, p1, p2, vars(o1), vars(p1), vars(p2))
+        assert repr(o1) == repr(o2)
