@@ -1,3 +1,4 @@
+# fmt: off
 import numpy as np
 import pytest
 
@@ -6,12 +7,11 @@ from ase.db import connect
 from ase.db.sqlite import all_tables
 
 
-def test_create_and_delete_ext_tab(testdir, get_db_name, dbtype):
+def test_create_and_delete_ext_tab(testdir):
     ext_tab = ["tab1", "tab2", "tab3"]
     atoms = Atoms()
 
-    name = get_db_name(dbtype)
-    db = connect(name)
+    db = connect('test.db')
     db.write(atoms)
 
     for tab in ext_tab:
@@ -24,11 +24,10 @@ def test_create_and_delete_ext_tab(testdir, get_db_name, dbtype):
     assert "tab1" not in db._get_external_table_names()
 
 
-def test_insert_in_external_tables(testdir, get_db_name, dbtype):
+def test_insert_in_external_tables(testdir):
     atoms = Atoms()
 
-    name = get_db_name(dbtype)
-    db = connect(name)
+    db = connect('test.db')
 
     # Now a table called insert_tab with schema datatype REAL should
     # be created
@@ -118,11 +117,10 @@ def test_insert_in_external_tables(testdir, get_db_name, dbtype):
             db.write(atoms, external_tables={tab_name: {"value": 1}})
 
 
-def test_extract_from_table(testdir, get_db_name, dbtype):
+def test_extract_from_table(testdir):
     atoms = Atoms()
 
-    name = get_db_name(dbtype)
-    db = connect(name)
+    db = connect('test.db')
     uid = db.write(
         atoms,
         external_tables={
@@ -136,11 +134,10 @@ def test_extract_from_table(testdir, get_db_name, dbtype):
     assert abs(row["insert_tab"]["rate1"] + 10.0) < 1E-8
 
 
-def test_write_atoms_row(testdir, get_db_name, dbtype):
+def test_write_atoms_row(testdir):
     atoms = Atoms()
 
-    name = get_db_name(dbtype)
-    db = connect(name)
+    db = connect('test.db')
     uid = db.write(
         atoms, external_tables={
             "insert_tab": {"rate": 12.0, "rate1": -10.0},
@@ -152,9 +149,8 @@ def test_write_atoms_row(testdir, get_db_name, dbtype):
     db.write(row)
 
 
-def test_external_table_upon_update(testdir, get_db_name, dbtype):
-    name = get_db_name(dbtype)
-    db = connect(name)
+def test_external_table_upon_update(testdir):
+    db = connect('test.db')
     no_features = 500
     ext_table = {i: i for i in range(no_features)}
     atoms = Atoms('Pb', positions=[[0, 0, 0]])
@@ -162,9 +158,8 @@ def test_external_table_upon_update(testdir, get_db_name, dbtype):
     db.update(uid, external_tables={'sys': ext_table})
 
 
-def test_external_table_upon_update_with_float(testdir, get_db_name, dbtype):
-    name = get_db_name(dbtype)
-    db = connect(name)
+def test_external_table_upon_update_with_float(testdir):
+    db = connect('test.db')
     ext_table = {'value1': 1.0, 'value2': 2.0}
     atoms = Atoms('Pb', positions=[[0, 0, 0]])
     uid = db.write(atoms)
