@@ -1,7 +1,9 @@
+# fmt: off
 import importlib.util
 import os
 import re
 import tempfile
+from functools import cached_property
 from pathlib import Path
 
 import pytest
@@ -14,7 +16,7 @@ from ase.calculators.castep import Castep, get_castep_version
 from ase.calculators.cp2k import CP2K, Cp2kShell
 from ase.calculators.dftb import Dftb
 from ase.calculators.dftd3 import DFTD3
-from ase.calculators.elk import ELK
+from ase.calculators.elk import ELK, ElkTemplate
 from ase.calculators.espresso import Espresso, EspressoTemplate
 from ase.calculators.exciting.exciting import (
     ExcitingGroundStateCalculator,
@@ -30,7 +32,6 @@ from ase.calculators.siesta import Siesta
 from ase.calculators.vasp import Vasp, get_vasp_version
 from ase.config import Config
 from ase.io.espresso import Namelist
-from ase.utils import lazyproperty
 
 
 class NotInstalled(Exception):
@@ -45,7 +46,7 @@ Could not import asetest package.  Please install ase-datafiles
 using e.g. "pip install ase-datafiles" to run calculator integration
 tests.""")
 
-    @lazyproperty
+    @cached_property
     def datafiles_module(self):
         try:
             import asetest
@@ -53,7 +54,7 @@ tests.""")
             return None
         return asetest
 
-    @lazyproperty
+    @cached_property
     def datafile_config(self):
         # XXXX TODO avoid requiring the dummy [parallel] section
         datafiles = self.datafiles_module
@@ -90,7 +91,7 @@ pseudo_path = {path}/siesta
 """
         return datafile_config
 
-    @lazyproperty
+    @cached_property
     def cfg(self):
         # First we load the usual configfile.
         # But we don't want to run tests against the user's production
@@ -249,13 +250,11 @@ class DFTD3Factory:
 @factory('elk')
 class ElkFactory:
     def __init__(self, cfg):
-        self.profile = ELK.load_argv_profile(cfg, 'elk')
+        self.profile = ElkTemplate().load_profile(cfg)
         self.species_dir = cfg.parser['elk']['species_dir']
 
     def version(self):
-        output = read_stdout(self.profile._split_command)
-        match = re.search(r'Elk code version (\S+)', output, re.M)
-        return match.group(1)
+        return self.profile.version()
 
     def calc(self, **kwargs):
         return ELK(profile=self.profile, species_dir=self.species_dir, **kwargs)
@@ -269,7 +268,7 @@ class EspressoFactory:
     def version(self):
         return self.profile.version()
 
-    @lazyproperty
+    @cached_property
     def pseudopotentials(self):
         pseudopotentials = {}
         for path in Path(self.profile.pseudo_dir).glob('*.UPF'):
