@@ -1,9 +1,11 @@
+# fmt: off
 from itertools import product
 
 import numpy as np
 import pytest
 
 import ase
+from ase import Atoms
 from ase.build import bulk
 from ase.calculators.test import gradient_test
 from ase.filters import ExpCellFilter, Filter, FrechetCellFilter, UnitCellFilter
@@ -27,8 +29,8 @@ def atoms(asap3) -> ase.Atoms:
 @pytest.mark.parametrize(
     'cellfilter', [UnitCellFilter, FrechetCellFilter, ExpCellFilter]
 )
-def test_get_and_set_positions(atoms, cellfilter):
-    filter: Filter = cellfilter(atoms)
+def test_get_and_set_positions(atoms: Atoms, cellfilter: type[Filter]) -> None:
+    filter = cellfilter(atoms)
     pos = filter.get_positions()
     filter.set_positions(pos)
     pos2 = filter.get_positions()
@@ -86,8 +88,8 @@ def test_cellfilter_stress(
     # Check gradient at other than origin
     natoms = len(atoms)
     pos0 = filter.get_positions()
-    np.random.seed(0)
-    pos0[natoms:, :] += 1e-2 * np.random.randn(3, 3)
+    rng = np.random.RandomState(0)
+    pos0[natoms:, :] += 1e-2 * rng.randn(3, 3)
     filter.set_positions(pos0)
     grads_actual = -filter.get_forces()
 
