@@ -1,3 +1,4 @@
+# fmt: off
 # additional tests of the extended XYZ file I/O
 # (which is also included in oi.py test case)
 # maintained by James Kermode <james.kermode@gmail.com>
@@ -324,14 +325,17 @@ def test_json_scalars():
     assert abs(b.info['val_3'] - 42) == 0
 
 
+@pytest.mark.parametrize(
+    'columns',
+    [None, ['symbols', 'positions', 'move_mask']],
+)
 @pytest.mark.parametrize('constraint', [FixAtoms(indices=(0, 2)),
                                         FixCartesian(1, mask=(1, 0, 1)),
                                         [FixCartesian(0), FixCartesian(2)]])
-def test_constraints(constraint):
+def test_constraints(constraint, columns):
     atoms = molecule('H2O')
     atoms.set_constraint(constraint)
 
-    columns = ['symbols', 'positions', 'move_mask']
     ase.io.write('tmp.xyz', atoms, columns=columns)
 
     atoms2 = ase.io.read('tmp.xyz')
@@ -501,3 +505,10 @@ def test_linear_combination_calculator():
     atoms.calc = LinearCombinationCalculator([EMT()], [1.0])
     atoms.get_potential_energy()
     atoms.write('tmp.xyz')
+
+
+def test_outputs_not_properties(tmp_path):
+    atoms = Atoms('Cu2', cell=[4, 2, 2], positions=[[0, 0, 0], [2.05, 0, 0]],
+                  pbc=[True] * 3, info={'nbands': 1})
+    ase.io.write(tmp_path / 'nbands.extxyz', atoms)
+    _ = ase.io.read(tmp_path / 'nbands.extxyz')
