@@ -1,3 +1,4 @@
+# fmt: off
 # type: ignore
 import numpy as np
 
@@ -221,7 +222,7 @@ def test_rmc6f_write_output():
     """
     header_lines = [
         '(Version 6f format configuration file)',
-        '(Generated by ASE - Atomic Simulation Environment https://wiki.fysik.dtu.dk/ase/ )',  # noqa: E501
+        '(Generated by ASE - Atomic Simulation Environment https://ase-lib.org/ )',  # noqa: E501
         "Metadata date:18-007-'2019",
         'Number of types of atoms:   2 ',
         'Atom types present:          S F',
