@@ -1,4 +1,3 @@
-# type: ignore
 import io
 import os
 import unittest
@@ -112,15 +111,23 @@ indices_to_constrain = [0, 2]
 
 @pytest.fixture()
 def graphene_atoms():
-    atoms = graphene_nanoribbon(2, 2, type="armchair", saturated=False)
+    atoms = graphene_nanoribbon(2, 2, type='armchair', saturated=False)
     atoms.cell = [[10, 0, 0], [0, 10, 0], [0, 0, 10]]
     return atoms
 
 
 def poscar_roundtrip(atoms):
     """Write a POSCAR file, read it back and return the new atoms object"""
-    atoms.write("POSCAR", direct=True)
-    return ase.io.read("POSCAR")
+    atoms.write('POSCAR', direct=True)
+    return ase.io.read('POSCAR')
+
+
+@pytest.mark.parametrize('whitespace', ['\n', '   ', '   \n\n  \n'])
+def test_with_whitespace(graphene_atoms, whitespace):
+    graphene_atoms.write('POSCAR', direct=True)
+    with open('POSCAR', 'a') as fd:
+        fd.write(whitespace)
+    assert str(ase.io.read('POSCAR').symbols) == str(graphene_atoms.symbols)
 
 
 def test_FixAtoms(graphene_atoms):
@@ -157,3 +164,15 @@ def test_FixedLine_and_Plane(ConstraintClass, graphene_atoms):
     # or FixedPlane is along a lattice vector.
 
     assert np.all(constrained_indices(new_atoms) == indices_to_constrain)
+
+
+def test_write_read_velocities(graphene_atoms):
+    vel = np.zeros_like(graphene_atoms.positions)
+    vel = np.linspace(-1, 1, 3 * len(graphene_atoms)).reshape(-1, 3)
+    graphene_atoms.set_velocities(vel)
+
+    graphene_atoms.write('CONTCAR', direct=False)
+    new_atoms = ase.io.read('CONTCAR')
+    new_vel = new_atoms.get_velocities()
+
+    assert np.allclose(vel, new_vel)
