@@ -59,6 +59,7 @@ def guifactory(display):
         gui = GUI(images)
         guis.append(gui)
         return gui
+
     yield factory
 
     for gui in guis:
@@ -154,6 +155,16 @@ def test_settings(gui):
     s.scale_radii()
 
 
+def test_magmom_arrows(gui):
+    gui.window['toggle-show-magmoms'] = True
+    gui.new_atoms(molecule('O2'))
+    s = gui.settings()
+    gui.magmom_vector_scale = 0.5
+    s.magmom_vector_scale.value = 2.1
+    s.scale_magmom_vectors()
+    assert gui.magmom_vector_scale == pytest.approx(2.1)
+
+
 def test_rotate(gui):
     gui.window['toggle-show-bonds'] = True
     gui.new_atoms(molecule('H2O'))
@@ -168,10 +179,17 @@ def test_open_and_save(gui, testdir):
     save_dialog(gui, 'h2o.cif@-1')
 
 
-@pytest.mark.parametrize('filename', [
-    None, 'output.png', 'output.eps',
-    'output.pov', 'output.traj', 'output.traj@0',
-])
+@pytest.mark.parametrize(
+    'filename',
+    [
+        None,
+        'output.png',
+        'output.eps',
+        'output.pov',
+        'output.traj',
+        'output.traj@0',
+    ],
+)
 def test_export_graphics(gui, testdir, with_bulk_ti, monkeypatch, filename):
     # Monkeypatch the blocking dialog:
     monkeypatch.setattr(ui.SaveFileDialog, 'go', lambda event: filename)
@@ -231,6 +249,7 @@ def test_select_atoms(gui, with_bulk_ti):
 def test_modify_element(gui, modify):
     class MockElement:
         Z = 79
+
     modify.set_element(MockElement())
     assert all(gui.atoms.symbols[:4] == 'Au')
     assert all(gui.atoms.symbols[4:] == 'Ti')
@@ -326,6 +345,7 @@ def test_reciprocal(gui):
     reciprocal = gui.reciprocal()
     reciprocal.terminate()
     exitcode = reciprocal.wait(timeout=5)
+    reciprocal.stdout.close()
     assert exitcode != 0
 
 
@@ -442,11 +462,39 @@ def test_clipboard_paste_onto_existing(gui):
     assert gui.atoms == ti + h2o
 
 
-@pytest.mark.parametrize('text', [
-    '',
-    'invalid_atoms',
-    '[1, 2, 3]',  # valid JSON but not Atoms
-])
+def test_wrap(gui):
+    """Test the Wrap atoms function."""
+    atoms = bulk('Si')
+    atoms.positions += 1234
+    gui.new_atoms(atoms)
+    unwrapped = atoms.get_scaled_positions(wrap=False)
+    wrapped_ref = atoms.get_scaled_positions(wrap=True)
+
+    assert (unwrapped > 1).all()
+    gui.wrap_atoms()
+    wrapped = gui.images[0].get_scaled_positions(wrap=False)
+    assert (wrapped < 1).all()
+    assert (wrapped >= 0).all()
+    assert wrapped == pytest.approx(wrapped_ref)
+
+
+def test_show_labels(gui):
+    atoms = molecule('CH3CH2OH')
+    gui.new_atoms(atoms)
+    assert gui.get_labels() is None
+    gui.window['show-labels'] = 3  # ugly: magical code for chemical symbols
+    gui.draw()
+    assert list(gui.get_labels()) == list(atoms.symbols)
+
+
+@pytest.mark.parametrize(
+    'text',
+    [
+        '',
+        'invalid_atoms',
+        '[1, 2, 3]',  # valid JSON but not Atoms
+    ],
+)
 def test_clipboard_paste_invalid(gui, text):
     gui.clipboard.set_text(text)
     with pytest.raises(GUIError):
@@ -454,12 +502,13 @@ def test_clipboard_paste_invalid(gui, text):
 
 
 def window():
-
     def hello(event=None):
         print('hello', event)
 
-    menu = [('Hi', [ui.MenuItem('_Hello', hello, 'Ctrl+H')]),
-            ('Hell_o', [ui.MenuItem('ABC', hello, choices='ABC')])]
+    menu = [
+        ('Hi', [ui.MenuItem('_Hello', hello, 'Ctrl+H')]),
+        ('Hell_o', [ui.MenuItem('ABC', hello, choices='ABC')]),
+    ]
     win = ui.MainWindow('Test', menu=menu)
 
     win.add(ui.Label('Hello'))
@@ -499,3 +548,58 @@ def runcallbacks(win):
 def test_callbacks(display):
     win = window()
     win.win.after_idle(runcallbacks)
+
+
+def test_atoms_editor_set_values(gui, atoms):
+    editor = gui.atoms_editor()
+
+    assert str(atoms.symbols) == 'Ti16'
+    entry, apply_change = editor.edit_field(row_id='R3', column_id='#1')
+    entry.delete(0, 'end')
+    entry.insert(0, 'Pu')
+    apply_change()
+
+    assert str(atoms.symbols) == 'Ti3PuTi12'
+
+    for i in range(3):
+        # Edit each coordinate:
+        entry, apply_change = editor.edit_field('R4', f'#{2 + i}')
+        entry.delete(0, 'end')
+        value = str(5.1 + i)
+        entry.insert(0, value)
+        apply_change()
+
+    assert atoms.positions[4] == pytest.approx([5.1, 6.1, 7.1])
+
+
+def test_atoms_editor_change_listener(gui, atoms):
+    editor = gui.atoms_editor()
+    entry, _ = editor.edit_field('R2', '#1')
+    assert entry.get() == 'Ti'
+    editor.leave_edit_mode()
+
+    atoms = molecule('CH3CH2OH')
+    gui.new_atoms(atoms)
+    entry, _ = editor.edit_field('R2', '#1')
+    assert entry.get() == 'O'
+
+
+def test_atoms_editor_select_in_gui(gui, atoms):
+    """Test that contents of editor updates when atoms change."""
+    editor = gui.atoms_editor()
+    assert sum(gui.images.selected) == 0
+    assert len(editor.treeview.selection()) == 0
+
+    gui.set_selected_atoms([2, 5, 6])
+    selection = editor.treeview.selection()
+    assert selection == ('R2', 'R5', 'R6')
+
+
+def test_atoms_editor_select_in_editor(gui, atoms):
+    """Test that GUI selection changes when editor selection does."""
+    editor = gui.atoms_editor()
+    editor.treeview.selection_set('R6', 'R7', 'R8', 'R10')
+    editor.treeview.event_generate('<<TreeviewSelect>>')
+    print(gui.images.selected)
+    assert all(gui.images.selected[[6, 7, 8, 10]])
+    assert sum(gui.images.selected) == 4
