@@ -1,3 +1,6 @@
+# fmt: off
+from pathlib import Path
+
 import pytest
 
 from ase.build import bulk
@@ -97,7 +100,8 @@ def test_unconverged(optcls, atoms, kwargs):
     fmax = 1e-9  # small value to not get converged
     with optcls(atoms, **kwargs) as opt:
         opt.run(fmax=fmax, steps=1)  # only one step to not get converged
-    assert not opt.converged()
+    gradient = opt.optimizable.get_gradient()
+    assert not opt.converged(gradient)
     assert opt.todict()["fmax"] == 1e-9
 
 
@@ -110,3 +114,13 @@ def test_run_twice(optcls, atoms, kwargs):
         opt.run(fmax=fmax, steps=steps)
     assert opt.nsteps == 2 * steps
     assert opt.max_steps == 2 * steps
+
+
+@pytest.mark.optimize()
+@pytest.mark.filterwarnings("ignore: estimate_mu")
+def test_path(testdir, optcls, atoms, kwargs):
+    fmax = 0.01
+    traj, log = Path('trajectory.traj'), Path('relax.log')
+    with optcls(atoms, logfile=log, trajectory=traj, **kwargs) as opt:
+        is_converged = opt.run(fmax=fmax)
+    assert is_converged  # check if opt.run() returns True when converged
