@@ -1,3 +1,5 @@
+# fmt: off
+
 """Modules for calculating thermochemical information from computational
 outputs."""
 
@@ -6,6 +8,7 @@ import sys
 from warnings import warn
 
 import numpy as np
+from scipy.integrate import trapezoid
 
 from ase import units
 
@@ -704,18 +707,18 @@ class CrystalThermo(ThermoChem):
 
         zpe_list = omega_e / 2.
         if self.formula_units == 0:
-            zpe = np.trapz(zpe_list * dos_e, omega_e)
+            zpe = trapezoid(zpe_list * dos_e, omega_e)
         else:
-            zpe = np.trapz(zpe_list * dos_e, omega_e) / self.formula_units
+            zpe = trapezoid(zpe_list * dos_e, omega_e) / self.formula_units
         write(fmt % ('E_ZPE', zpe))
         U += zpe
 
         B = 1. / (units.kB * temperature)
         E_vib = omega_e / (np.exp(omega_e * B) - 1.)
         if self.formula_units == 0:
-            E_phonon = np.trapz(E_vib * dos_e, omega_e)
+            E_phonon = trapezoid(E_vib * dos_e, omega_e)
         else:
-            E_phonon = np.trapz(E_vib * dos_e, omega_e) / self.formula_units
+            E_phonon = trapezoid(E_vib * dos_e, omega_e) / self.formula_units
         write(fmt % ('E_phonon', E_phonon))
         U += E_phonon
 
@@ -750,9 +753,9 @@ class CrystalThermo(ThermoChem):
         S_vib = (omega_e / (temperature * (np.exp(omega_e * B) - 1.)) -
                  units.kB * np.log(1. - np.exp(-omega_e * B)))
         if self.formula_units == 0:
-            S = np.trapz(S_vib * dos_e, omega_e)
+            S = trapezoid(S_vib * dos_e, omega_e)
         else:
-            S = np.trapz(S_vib * dos_e, omega_e) / self.formula_units
+            S = trapezoid(S_vib * dos_e, omega_e) / self.formula_units
 
         write('-' * 49)
         write(fmt % ('S', S, S * temperature))
