@@ -3,9 +3,15 @@ import numpy as np
 from ase.eos import birchmurnaghan
 
 
-def delta(v1: float, B1: float, Bp1: float,
-          v2: float, B2: float, Bp2: float,
-          symmetric=True) -> float:
+def delta(
+    v1: float,
+    B1: float,
+    Bp1: float,
+    v2: float,
+    B2: float,
+    Bp2: float,
+    symmetric=True,
+) -> float:
     """Calculate Delta-value between two equation of states.
 
     .. seealso:: https://github.com/molmod/DeltaCodesDFT
@@ -37,4 +43,4 @@ def delta(v1: float, B1: float, Bp1: float,
     v = np.linspace(va + dv / 2, vb - dv / 2, npoints)
     e1 = birchmurnaghan(v, 0.0, B1, Bp1, v1)
     e2 = birchmurnaghan(v, 0.0, B2, Bp2, v2)
-    return (((e1 - e2)**2).sum() * dv / (vb - va))**0.5
+    return (((e1 - e2) ** 2).sum() * dv / (vb - va)) ** 0.5
