@@ -56,14 +56,16 @@ def get_version():
 
 
 def main():
-    p = argparse.ArgumentParser(description='Generate new release of ASE.',
-                                epilog='Run from the root directory of ASE.')
-    p.add_argument('version', nargs=1,
-                   help='version number for new release')
+    p = argparse.ArgumentParser(
+        description='Generate new release of ASE.',
+        epilog='Run from the root directory of ASE.',
+    )
+    p.add_argument('version', nargs=1, help='version number for new release')
     # p.add_argument('nextversion', nargs=1,
     #                help='development version after release')
-    p.add_argument('--clean', action='store_true',
-                   help='delete release branch and tag')
+    p.add_argument(
+        '--clean', action='store_true', help='delete release branch and tag'
+    )
     args = p.parse_args()
 
     assert versionfile.name == '__init__.py'
@@ -72,26 +74,33 @@ def main():
     try:
         current_version = get_version()
     except Exception as err:
-        p.error('Cannot get version: {}.  Are you in the root directory?'
-                .format(err))
+        p.error(
+            'Cannot get version: {}.  Are you in the root directory?'.format(
+                err
+            )
+        )
 
     print(f'Current version: {current_version}')
 
     version = args.version[0]
 
-    branchname = f'ase-{version}'
+    # branchname = f'ase-{version}'
     current_version = get_version()
 
     if args.clean:
         print(f'Cleaning {version}')
-        git('checkout master')
-        # git('tag -d {}'.format(version), error_ok=True)
-        git(f'branch -D {branchname}', error_ok=True)
-        # git('branch -D {}'.format('web-page'), error_ok=True)
+        # git('checkout master')
+        git(f'tag -d pre-{version}', error_ok=True)
+        # git(f'branch -D {branchname}', error_ok=True)
         return
 
     print(f'New release: {version}')
 
+    if shutil.which('scriv') is None:
+        p.error('No "scriv" command in PATH.  Is scriv installed?')
+
+    runcmd(f'scriv collect --add --title "Version {version}"')
+
     txt = git('status')
     branch = re.match(r'On branch (\S+)', txt).group(1)
 
@@ -113,7 +122,8 @@ def main():
     match_and_edit_version(
         versionfile,
         pattern='__version__ = ',
-        replacement=f"__version__ = '{version}'")
+        replacement=f"__version__ = '{version}'",
+    )
 
     releasenotes = ase_toplevel / 'doc/releasenotes.rst'
 
@@ -142,8 +152,9 @@ Git master branch
     date = strftime('%d %B %Y').lstrip('0')
     header = f'Version {version}'
     underline = '=' * len(header)
-    replacetxt = replacetxt.format(header=header, version=version,
-                                   underline=underline, date=date)
+    replacetxt = replacetxt.format(
+        header=header, version=version, underline=underline, date=date
+    )
 
     print(f'Editing {releasenotes}')
     with open(releasenotes) as fd:
@@ -184,23 +195,24 @@ News
     with open(installdoc) as fd:
         txt = fd.read()
 
-    txt, nsub = re.subn(r'ase-\d+\.\d+\.\d+',
-                        f'ase-{version}', txt)
+    txt, nsub = re.subn(r'ase-\d+\.\d+\.\d+', f'ase-{version}', txt)
     assert nsub > 0
-    txt, nsub = re.subn(r'git clone -b \d+\.\d+\.\d+',
-                        f'git clone -b {version}', txt)
+    txt, nsub = re.subn(
+        r'git clone -b \d+\.\d+\.\d+', f'git clone -b {version}', txt
+    )
     assert nsub == 1
 
     with open(installdoc, 'w') as fd:
         fd.write(txt)
 
     print(f'Creating new release from branch {branch!r}')
-    git(f'checkout -b {branchname}')
+    # git(f'checkout -b {branchname}')
 
     edited_paths = [versionfile, installdoc, frontpage, releasenotes]
 
     git('add {}'.format(' '.join(str(path) for path in edited_paths)))
     git(f'commit -m "ASE version {version}"')
+    git(f'tag pre-{version}')
     # git('tag -s {0} -m "ase-{0}"'.format(version))
 
     buildpath = Path('build')
@@ -229,11 +241,13 @@ News
     print('===============')
     print(f'git show {version}  # Inspect!')
     print('git checkout master')
-    print(f'git merge {branchname}')
-    print('twine upload '
-          'dist/ase-{v}.tar.gz '
-          'dist/ase-{v}-py3-none-any.whl '
-          'dist/ase-{v}.tar.gz.asc'.format(v=version))
+    # print(f'git merge {branchname}')
+    print(
+        'twine upload '
+        'dist/ase-{v}.tar.gz '
+        'dist/ase-{v}-py3-none-any.whl '
+        'dist/ase-{v}.tar.gz.asc'.format(v=version)
+    )
     print('git push --tags origin master  # Assuming your remote is "origin"')
 
 
