@@ -1,19 +1,20 @@
-from typing import Optional
+from typing import Any, Optional
 
 import matplotlib.pyplot as plt
 from matplotlib.axes import Axes
-from matplotlib.figure import Figure
 
 
 class SimplePlottingAxes:
-    def __init__(self,
-                 ax: Optional[Axes] = None,
-                 show: bool = False,
-                 filename: str = None) -> None:
+    def __init__(
+        self,
+        ax: Optional[Axes] = None,
+        show: bool = False,
+        filename: str = None,
+    ) -> None:
         self.ax = ax
         self.show = show
         self.filename = filename
-        self.figure: Optional[Figure] = None
+        self.figure: Any = None  # Don't know about Figure/SubFigure etc
 
     def __enter__(self) -> Axes:
         if self.ax is None:
@@ -27,8 +28,9 @@ class SimplePlottingAxes:
         if exc_type is None:
             # If there was no exception, display/write the plot as appropriate
             if self.figure is None:
-                raise Exception("Something went wrong initializing matplotlib "
-                                "figure")
+                raise Exception(
+                    'Something went wrong initializing matplotlib figure'
+                )
             if self.show:
                 self.figure.show()
             if self.filename is not None:
