@@ -1,3 +1,5 @@
+# fmt: off
+
 """Storage and analysis for vibrational data"""
 
 import collections
@@ -127,7 +129,8 @@ class VibrationsData:
                 range(
                     len(atoms))),
             const_indices).astype(int)
-        return indices.tolist()
+        # TODO: use numpy.typing to resolve this error.
+        return indices.tolist()  # type: ignore[return-value]
 
     @staticmethod
     def indices_from_mask(mask: Union[Sequence[bool], np.ndarray]
@@ -153,7 +156,8 @@ class VibrationsData:
             indices of True elements
 
         """
-        return np.where(mask)[0].tolist()
+        # TODO: use numpy.typing to resolve this error.
+        return np.where(mask)[0].tolist()  # type: ignore[return-value]
 
     @staticmethod
     def _check_dimensions(atoms: Atoms,
@@ -399,11 +403,6 @@ class VibrationsData:
     def get_zero_point_energy(self) -> float:
         """Diagonalise the Hessian and sum hw/2 to obtain zero-point energy
 
-        Args:
-            energies:
-                Pre-computed energy eigenvalues. Use if available to avoid
-                re-calculating these from the Hessian.
-
         Returns:
             zero-point energy in eV
         """
