@@ -6,11 +6,11 @@ from ase.calculators.dftd3 import DFTD3
 from ase.constraints import UnitCellFilter
 from ase.optimize import LBFGS
 
-np.random.seed(0)
+rng = np.random.RandomState(0)
 
 diamond = bulk('C')
-diamond.rattle(stdev=0.1, seed=0)
-diamond.cell += np.random.normal(scale=0.1, size=(3, 3))
+diamond.rattle(stdev=0.1, rng=rng)
+diamond.cell += rng.normal(scale=0.1, size=(3, 3))
 dft = GPAW(xc='PBE', kpts=(8, 8, 8), mode=PW(400))
 d3 = DFTD3(dft=dft)
 diamond.calc = d3
