@@ -7,11 +7,13 @@ from ase.optimize import BFGS
 
 unixsocket = 'siesta'
 
-fdf_arguments = {'MD.TypeOfRun': 'Master',
-                 'Master.code': 'i-pi',
-                 'Master.interface': 'socket',
-                 'Master.address': unixsocket,
-                 'Master.socketType': 'unix'}
+fdf_arguments = {
+    'MD.TypeOfRun': 'Master',
+    'Master.code': 'i-pi',
+    'Master.interface': 'socket',
+    'Master.address': unixsocket,
+    'Master.socketType': 'unix',
+}
 
 # To connect through INET socket instead, use:
 #   fdf_arguments['Master.port'] = port
@@ -22,11 +24,10 @@ fdf_arguments = {'MD.TypeOfRun': 'Master',
 atoms = molecule('H2O', vacuum=3.0)
 atoms.rattle(stdev=0.1)
 
-siesta = Siesta(fdf_arguments=fdf_arguments)
+siesta = Siesta(directory='siesta-calc', fdf_arguments=fdf_arguments)
 opt = BFGS(atoms, trajectory='opt.siesta.traj', logfile='opt.siesta.log')
 
-with SocketIOCalculator(siesta, log=sys.stdout,
-                        unixsocket=unixsocket) as calc:
+with SocketIOCalculator(siesta, log=sys.stdout, unixsocket=unixsocket) as calc:
     atoms.calc = calc
     opt.run(fmax=0.05)
 
