@@ -3,11 +3,13 @@ import matplotlib.pyplot as plt
 
 from ase.phasediagram import PhaseDiagram
 
-refs = [('Cu', 0.0),
-        ('Au', 0.0),
-        ('CuAu2', -0.2),
-        ('CuAu', -0.5),
-        ('Cu2Au', -0.7)]
+refs = [
+    ('Cu', 0.0),
+    ('Au', 0.0),
+    ('CuAu2', -0.2),
+    ('CuAu', -0.5),
+    ('Cu2Au', -0.7),
+]
 pd = PhaseDiagram(refs)
 pd.plot(show=False)
 plt.savefig('cuau.png')
