@@ -9,13 +9,18 @@ atoms = Cluster('relaxed.traj')
 atoms.minimal_box(3.5, h=h)
 
 # relax the molecule
-calc = GPAW(h=h, occupations=FermiDirac(width=0.1),
-            eigensolver='cg', symmetry={'point_group': False},
-            nbands=10, convergence={'eigenstates': 1.e-5,
-                                    'bands': 4})
+calc = GPAW(
+    h=h,
+    occupations=FermiDirac(width=0.1),
+    eigensolver='cg',
+    symmetry={'point_group': False},
+    nbands=10,
+    convergence={'eigenstates': 1.0e-5, 'bands': 4},
+)
 atoms.calc = calc
 
 # use only the 4 converged states for linear response calculation
-rmc = ResonantRamanCalculator(atoms, LrTDDFT,
-                              exkwargs={'restrict': {'jend': 3}})
+rmc = ResonantRamanCalculator(
+    atoms, LrTDDFT, exkwargs={'restrict': {'jend': 3}}
+)
 rmc.run()
