@@ -6,8 +6,9 @@ from ase.cluster.cubic import FaceCenteredCubic
 from ase.utils.xrdebye import XrDebye
 
 # create nanoparticle with approx. 2 nm diameter
-atoms = FaceCenteredCubic('Ag', [(1, 0, 0), (1, 1, 0), (1, 1, 1)],
-                          [6, 8, 8], 4.09)
+atoms = FaceCenteredCubic(
+    'Ag', [(1, 0, 0), (1, 1, 0), (1, 1, 1)], [6, 8, 8], 4.09
+)
 # setup for desired wavelength
 xrd = XrDebye(atoms=atoms, wavelength=0.50523)
 # calculate and plot diffraction pattern
