@@ -13,5 +13,6 @@ for i, s in enumerate(t):
 
     ofname = str(i) + '.png'
     print('writing', ofname)
-    io.write(ofname, s,
-             bbox=[-3, -5, 50, 22])  # set bbox by hand, try and error
+    io.write(
+        ofname, s, bbox=[-3, -5, 50, 22]
+    )  # set bbox by hand, try and error
