@@ -12,13 +12,12 @@ from ase.build import fcc111
 from ase.io import read, write
 
 a = 3.55
-atoms = Atoms('Ni4',
-              cell=[sqrt(2) * a, sqrt(2) * a, 1.0, 90, 90, 120],
-              pbc=(1, 1, 0),
-              scaled_positions=[(0, 0, 0),
-                                (0.5, 0, 0),
-                                (0, 0.5, 0),
-                                (0.5, 0.5, 0)])
+atoms = Atoms(
+    'Ni4',
+    cell=[sqrt(2) * a, sqrt(2) * a, 1.0, 90, 90, 120],
+    pbc=(1, 1, 0),
+    scaled_positions=[(0, 0, 0), (0.5, 0, 0), (0, 0.5, 0), (0.5, 0.5, 0)],
+)
 atoms.center(vacuum=5.0, axis=2)
 write('a1.png', atoms, rotation='-73x')
 a3 = atoms.repeat((3, 3, 2))
