@@ -9,12 +9,15 @@ a = 4.6
 c = 2.95
 
 # Rutile TiO2:
-atoms = crystal(['Ti', 'O'], basis=[(0, 0, 0), (0.3, 0.3, 0.0)],
-                spacegroup=136, cellpar=[a, a, c, 90, 90, 90])
+atoms = crystal(
+    ['Ti', 'O'],
+    basis=[(0, 0, 0), (0.3, 0.3, 0.0)],
+    spacegroup=136,
+    cellpar=[a, a, c, 90, 90, 90],
+)
 write('rutile.traj', atoms)
 
-calc = GPAW(mode=PW(800), kpts=[2, 2, 3],
-            txt='gpaw.rutile.txt')
+calc = GPAW(mode=PW(800), kpts=[2, 2, 3], txt='gpaw.rutile.txt')
 atoms.calc = calc
 
 opt = BFGS(ExpCellFilter(atoms), trajectory='opt.rutile.traj')
