@@ -25,28 +25,32 @@ da = DataConnection('gadb.db')
 tmp_folder = 'tmp_folder/'
 
 # An extra object is needed to handle the parallel execution
-parallel_local_run = ParallelLocalRun(data_connection=da,
-                                      tmp_folder=tmp_folder,
-                                      n_simul=4,
-                                      calc_script='calc.py')
+parallel_local_run = ParallelLocalRun(
+    data_connection=da, tmp_folder=tmp_folder, n_simul=4, calc_script='calc.py'
+)
 
 atom_numbers_to_optimize = da.get_atom_numbers_to_optimize()
 n_to_optimize = len(atom_numbers_to_optimize)
 slab = da.get_slab()
 all_atom_types = get_all_atom_types(slab, atom_numbers_to_optimize)
-blmin = closest_distances_generator(all_atom_types,
-                                    ratio_of_covalent_radii=0.7)
+blmin = closest_distances_generator(all_atom_types, ratio_of_covalent_radii=0.7)
 
-comp = InteratomicDistanceComparator(n_top=n_to_optimize,
-                                     pair_cor_cum_diff=0.015,
-                                     pair_cor_max=0.7,
-                                     dE=0.02,
-                                     mic=False)
+comp = InteratomicDistanceComparator(
+    n_top=n_to_optimize,
+    pair_cor_cum_diff=0.015,
+    pair_cor_max=0.7,
+    dE=0.02,
+    mic=False,
+)
 pairing = CutAndSplicePairing(slab, n_to_optimize, blmin)
-mutations = OperationSelector([1., 1., 1.],
-                              [MirrorMutation(blmin, n_to_optimize),
-                               RattleMutation(blmin, n_to_optimize),
-                               PermutationMutation(n_to_optimize)])
+mutations = OperationSelector(
+    [1.0, 1.0, 1.0],
+    [
+        MirrorMutation(blmin, n_to_optimize),
+        RattleMutation(blmin, n_to_optimize),
+        PermutationMutation(n_to_optimize),
+    ],
+)
 
 # Relax all unrelaxed structures (e.g. the starting population)
 while da.get_number_of_unrelaxed_candidates() > 0:
@@ -55,12 +59,12 @@ while da.get_number_of_unrelaxed_candidates() > 0:
 
 # Wait until the starting population is relaxed
 while parallel_local_run.get_number_of_jobs_running() > 0:
-    time.sleep(5.)
+    time.sleep(5.0)
 
 # create the population
-population = Population(data_connection=da,
-                        population_size=population_size,
-                        comparator=comp)
+population = Population(
+    data_connection=da, population_size=population_size, comparator=comp
+)
 
 # test n_to_test new candidates
 for i in range(n_to_test):
@@ -84,6 +88,6 @@ for i in range(n_to_test):
 
 # Wait until the last candidates are relaxed
 while parallel_local_run.get_number_of_jobs_running() > 0:
-    time.sleep(5.)
+    time.sleep(5.0)
 
 write('all_candidates.traj', da.get_all_relaxed_candidates())
