@@ -42,8 +42,12 @@ def jtg(job_name, traj_file):
 def combine_parameters(conf):
     # Get and combine selected parameters
     parameters = []
-    gets = [get_atoms_connections(conf) + get_rings(conf) +
-            get_angles_distribution(conf) + get_atoms_distribution(conf)]
+    gets = [
+        get_atoms_connections(conf)
+        + get_rings(conf)
+        + get_angles_distribution(conf)
+        + get_atoms_distribution(conf)
+    ]
     for get in gets:
         parameters += get
     return parameters
@@ -70,43 +74,52 @@ mutation_probability = 0.3
 da = DataConnection('gadb.db')
 tmp_folder = 'work_folder/'
 # The PBS queing interface is created
-pbs_run = PBSQueueRun(da,
-                      tmp_folder=tmp_folder,
-                      job_prefix='Ag2Au2_opt',
-                      n_simul=5,
-                      job_template_generator=jtg,
-                      find_neighbors=get_neighborlist,
-                      perform_parametrization=combine_parameters)
+pbs_run = PBSQueueRun(
+    da,
+    tmp_folder=tmp_folder,
+    job_prefix='Ag2Au2_opt',
+    n_simul=5,
+    job_template_generator=jtg,
+    find_neighbors=get_neighborlist,
+    perform_parametrization=combine_parameters,
+)
 
 atom_numbers_to_optimize = da.get_atom_numbers_to_optimize()
 n_to_optimize = len(atom_numbers_to_optimize)
 slab = da.get_slab()
 all_atom_types = get_all_atom_types(slab, atom_numbers_to_optimize)
-blmin = closest_distances_generator(all_atom_types,
-                                    ratio_of_covalent_radii=0.7)
+blmin = closest_distances_generator(all_atom_types, ratio_of_covalent_radii=0.7)
 
-comp = InteratomicDistanceComparator(n_top=n_to_optimize,
-                                     pair_cor_cum_diff=0.015,
-                                     pair_cor_max=0.7,
-                                     dE=0.02,
-                                     mic=False)
+comp = InteratomicDistanceComparator(
+    n_top=n_to_optimize,
+    pair_cor_cum_diff=0.015,
+    pair_cor_max=0.7,
+    dE=0.02,
+    mic=False,
+)
 pairing = CutAndSplicePairing(slab, n_to_optimize, blmin)
-mutations = OperationSelector([1., 1., 1.],
-                              [MirrorMutation(blmin, n_to_optimize),
-                               RattleMutation(blmin, n_to_optimize),
-                               PermutationMutation(n_to_optimize)])
+mutations = OperationSelector(
+    [1.0, 1.0, 1.0],
+    [
+        MirrorMutation(blmin, n_to_optimize),
+        RattleMutation(blmin, n_to_optimize),
+        PermutationMutation(n_to_optimize),
+    ],
+)
 
 # Relax all unrelaxed structures (e.g. the starting population)
-while (da.get_number_of_unrelaxed_candidates() > 0 and
-       not pbs_run.enough_jobs_running()):
+while (
+    da.get_number_of_unrelaxed_candidates() > 0
+    and not pbs_run.enough_jobs_running()
+):
     a = da.get_an_unrelaxed_candidate()
     pbs_run.relax(a)
 
 
 # create the population
-population = Population(data_connection=da,
-                        population_size=population_size,
-                        comparator=comp)
+population = Population(
+    data_connection=da, population_size=population_size, comparator=comp
+)
 
 # create the regression expression for estimating the energy
 all_trajs = da.get_all_relaxed_candidates()
@@ -127,8 +140,10 @@ else:
     weights = None
 
 # Submit new candidates until enough are running
-while (not pbs_run.enough_jobs_running() and
-       len(population.get_current_population()) > 2):
+while (
+    not pbs_run.enough_jobs_running()
+    and len(population.get_current_population()) > 2
+):
     a1, a2 = population.get_two_candidates()
 
     # Selecting the "worst" parent energy
@@ -146,8 +161,9 @@ while (not pbs_run.enough_jobs_running() and
 
     if random() < mutation_probability:
         a3_mut, desc_mut = mutations.get_new_individual([a3])
-        if (a3_mut is not None and
-                not should_we_skip(a3_mut, comparison_energy, weights)):
+        if a3_mut is not None and not should_we_skip(
+            a3_mut, comparison_energy, weights
+        ):
             da.add_unrelaxed_step(a3_mut, desc_mut)
             a3 = a3_mut
     pbs_run.relax(a3)
