@@ -33,44 +33,55 @@ mutation_probability = 0.3
 da = DataConnection('gadb.db')
 tmp_folder = 'tmp_folder/'
 # The PBS queing interface is created
-pbs_run = PBSQueueRun(da,
-                      tmp_folder=tmp_folder,
-                      job_prefix='Ag2Au2_opt',
-                      n_simul=5,
-                      job_template_generator=jtg)
+pbs_run = PBSQueueRun(
+    da,
+    tmp_folder=tmp_folder,
+    job_prefix='Ag2Au2_opt',
+    n_simul=5,
+    job_template_generator=jtg,
+)
 
 atom_numbers_to_optimize = da.get_atom_numbers_to_optimize()
 n_to_optimize = len(atom_numbers_to_optimize)
 slab = da.get_slab()
 all_atom_types = get_all_atom_types(slab, atom_numbers_to_optimize)
-blmin = closest_distances_generator(all_atom_types,
-                                    ratio_of_covalent_radii=0.7)
+blmin = closest_distances_generator(all_atom_types, ratio_of_covalent_radii=0.7)
 
-comp = InteratomicDistanceComparator(n_top=n_to_optimize,
-                                     pair_cor_cum_diff=0.015,
-                                     pair_cor_max=0.7,
-                                     dE=0.02,
-                                     mic=False)
+comp = InteratomicDistanceComparator(
+    n_top=n_to_optimize,
+    pair_cor_cum_diff=0.015,
+    pair_cor_max=0.7,
+    dE=0.02,
+    mic=False,
+)
 pairing = CutAndSplicePairing(slab, n_to_optimize, blmin)
-mutations = OperationSelector([1., 1., 1.],
-                              [MirrorMutation(blmin, n_to_optimize),
-                               RattleMutation(blmin, n_to_optimize),
-                               PermutationMutation(n_to_optimize)])
+mutations = OperationSelector(
+    [1.0, 1.0, 1.0],
+    [
+        MirrorMutation(blmin, n_to_optimize),
+        RattleMutation(blmin, n_to_optimize),
+        PermutationMutation(n_to_optimize),
+    ],
+)
 
 # Relax all unrelaxed structures (e.g. the starting population)
-while (da.get_number_of_unrelaxed_candidates() > 0 and
-       not pbs_run.enough_jobs_running()):
+while (
+    da.get_number_of_unrelaxed_candidates() > 0
+    and not pbs_run.enough_jobs_running()
+):
     a = da.get_an_unrelaxed_candidate()
     pbs_run.relax(a)
 
 # create the population
-population = Population(data_connection=da,
-                        population_size=population_size,
-                        comparator=comp)
+population = Population(
+    data_connection=da, population_size=population_size, comparator=comp
+)
 
 # Submit new candidates until enough are running
-while (not pbs_run.enough_jobs_running() and
-       len(population.get_current_population()) > 2):
+while (
+    not pbs_run.enough_jobs_running()
+    and len(population.get_current_population()) > 2
+):
     a1, a2 = population.get_two_candidates()
     a3, desc = pairing.get_new_individual([a1, a2])
     if a3 is None:
