@@ -15,8 +15,10 @@ for dct in dcts:
     refs.append((dct.formula, -dct.raw_score))
 
 pd = PhaseDiagram(refs)
-ax = pd.plot(show=not True,  # set to True to show plot
-             only_label_simplices=True)
+ax = pd.plot(
+    show=not True,  # set to True to show plot
+    only_label_simplices=True,
+)
 plt.savefig('hull.png')
 
 # View the simplices of the convex hull
