@@ -10,16 +10,20 @@ use_asap = False
 
 if use_asap:
     from asap3 import EMT
+
     size = 10
 else:
     from ase.calculators.emt import EMT
+
     size = 3
 
 # Set up a crystal
-atoms = FaceCenteredCubic(directions=[[1, 0, 0], [0, 1, 0], [0, 0, 1]],
-                          symbol='Cu',
-                          size=(size, size, size),
-                          pbc=True)
+atoms = FaceCenteredCubic(
+    directions=[[1, 0, 0], [0, 1, 0], [0, 0, 1]],
+    symbol='Cu',
+    size=(size, size, size),
+    pbc=True,
+)
 
 # Describe the interatomic interactions with the Effective Medium Theory
 atoms.calc = EMT()
@@ -35,8 +39,10 @@ def printenergy(a):
     """Function to print the potential, kinetic and total energy"""
     epot = a.get_potential_energy() / len(a)
     ekin = a.get_kinetic_energy() / len(a)
-    print('Energy per atom: Epot = %.3feV  Ekin = %.3feV (T=%3.0fK)  '
-          'Etot = %.3feV' % (epot, ekin, ekin / (1.5 * units.kB), epot + ekin))
+    print(
+        'Energy per atom: Epot = %.3feV  Ekin = %.3feV (T=%3.0fK)  '
+        'Etot = %.3feV' % (epot, ekin, ekin / (1.5 * units.kB), epot + ekin)
+    )
 
 
 # Now run the dynamics
