@@ -1,4 +1,5 @@
 """Demonstrates molecular dynamics for isolated particles."""
+
 from ase import units
 from ase.cluster.cubic import FaceCenteredCubic
 from ase.md.velocitydistribution import (
@@ -14,16 +15,20 @@ use_asap = True
 
 if use_asap:
     from asap3 import EMT
+
     size = 4
 else:
     from ase.calculators.emt import EMT
+
     size = 2
 
 # Set up a nanoparticle
-atoms = FaceCenteredCubic('Cu',
-                          surfaces=[[1, 0, 0], [1, 1, 0], [1, 1, 1]],
-                          layers=(size, size, size),
-                          vacuum=4)
+atoms = FaceCenteredCubic(
+    'Cu',
+    surfaces=[[1, 0, 0], [1, 1, 0], [1, 1, 1]],
+    layers=(size, size, size),
+    vacuum=4,
+)
 
 # Describe the interatomic interactions with the Effective Medium Theory
 atoms.calc = EMT()
@@ -47,8 +52,10 @@ def printenergy(a=atoms):  # store a reference to atoms in the definition.
     """Function to print the potential, kinetic and total energy."""
     epot = a.get_potential_energy() / len(a)
     ekin = a.get_kinetic_energy() / len(a)
-    print('Energy per atom: Epot = %.3feV  Ekin = %.3feV (T=%3.0fK)  '
-          'Etot = %.3feV' % (epot, ekin, ekin / (1.5 * units.kB), epot + ekin))
+    print(
+        'Energy per atom: Epot = %.3feV  Ekin = %.3feV (T=%3.0fK)  '
+        'Etot = %.3feV' % (epot, ekin, ekin / (1.5 * units.kB), epot + ekin)
+    )
 
 
 dyn.attach(printenergy, interval=10)
