@@ -16,8 +16,11 @@ for name, a in zip('ITF', images[::2]):
     del a.constraints
     a = a * (2, 2, 1)
     a.set_cell(cell)
-    renderer = write('diffusion-%s.pov' % name, a,
-                     povray_settings=dict(transparent=False, display=False))
+    renderer = write(
+        'diffusion-%s.pov' % name,
+        a,
+        povray_settings=dict(transparent=False, display=False),
+    )
     renderer.render()
 
 nebtools = NEBTools(images)
