@@ -16,12 +16,14 @@ interaction = LJInteractions({('O', 'O'): (epsilon0, sigma0)})
 embedding = Embedding(rc=0.02)  # Short range analytical potential cutoff
 
 # Set up calculator
-atoms.calc = EIQMMM(qm_idx,
-                    GPAW(txt='qm.out'),
-                    TIP3P(),
-                    interaction,
-                    embedding=embedding,
-                    vacuum=None,  # if None, QM cell = MM cell
-                    output='qmmm.log')
+atoms.calc = EIQMMM(
+    qm_idx,
+    GPAW(txt='qm.out'),
+    TIP3P(),
+    interaction,
+    embedding=embedding,
+    vacuum=None,  # if None, QM cell = MM cell
+    output='qmmm.log',
+)
 
 print(atoms.get_potential_energy())
